
****************************
***Descriptive Statistics***
****************************


***Figure 1: business cycle

{

*Unemployment rate FRA vs. USA
clear all
set more off
use  "$maindir_replication${sep}$Data${sep}Nomenclatures${sep}unemployment_rate_usa_fr.dta"

keep if  year>=1985
keep if  year<=2019

twoway (connected all year if country=="france", msymbol(th)) (connected all year if country=="usa", msymbol(O) msize(small)), title() subtitle() xlabel(1985(5)2020) xmtick(1985(1)2020) ylabel(3(1)11) ymtick() ytitle("(%)") xtitle("") legend(order(1 "France" 2 "United States")) note() graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure1A.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure1A.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure1A.png", as(png) replace

*Growth rate FRA vs. USA
clear all
set more off
use  "$maindir_replication${sep}$Data${sep}Nomenclatures${sep}growth_usa_fr.dta"

twoway (connected growth_fr year, msymbol(th)) (connected growth_us year, msymbol(O) msize(small)), title() subtitle() xlabel(1985(5)2020) xmtick(1985(1)2020) ylabel(-3(1)5) ymtick() ytitle("(%)") xtitle("") legend(order(1 "France" 2 "United States")) note() graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure1B.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure1B.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure1B.png", as(png) replace


}
*

***Figure 2: nominal and real minimum wage

{
clear all
set more off

use "$maindir_replication${sep}$Data${sep}Nomenclatures${sep}minimum_wage_fr.dta"

*Normalized to 0 in 1991
qui sum smic if year==1991
gen nsmic = log(smic)-log(r(mean))
sum smic_2018 if year==1991
gen nsmic_2018 = log(smic_2018)-log(r(mean))

*Nominal
twoway (line nsmic year), title() subtitle() xlabel(1991(5)2016) xmtick(1991(1)2018) ylabel(0(.2).8) ymtick() ytitle("Log hourly minimum wage relative to 1991") xtitle("") note() graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure2A.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure2A.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure2A.png", as(png) replace

*Real
twoway (line nsmic_2018 year) , title() subtitle() xlabel(1991(5)2016) xmtick(1991(1)2018) ylabel(0(.1).4) ymtick() ytitle("Log real hourly minimum wage relative to 1991") xtitle("") note() graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure2B.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure2B.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure2B.png", as(png) replace

}
*

***Figure 4: workweek

{
clear all
set more off

use "$maindir_replication${sep}$Data${sep}Nomenclatures${sep}hours_usa_fr.dta"

twoway (connected hours_fr year, msymbol(th)) (connected hours_us year, msymbol(O) msize(small)), title() subtitle() xlabel(1985(5)2020) xmtick(1985(1)2020) ylabel(1500(100)1900) ymtick(1500(50)1900) ytitle("") xtitle("") legend(order(1 "France" 2 "United States")) note() graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure4.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure4.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figure4.png", as(png) replace

}
*

***Figure B.1: participation rate by age group

{
clear all
set more off

*Figure B1A
*Participation rate for people aged 25-64

clear all
set more off
use "$maindir_replication${sep}$Data${sep}Nomenclatures${sep}participation_usa_fr.dta"

twoway (connected participation_fr year, msymbol(th)) (connected participation_us year, msymbol(O) msize(small)), title() subtitle() xlabel(1980(5)2020) xmtick(1980(1)2020) ymtick(72(2)80) ytitle("") xtitle("") legend(order(1 "France" 2 "United States")) note() graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1A.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1A.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1A.png", as(png) replace


*Figure B1B
*Participation rate for people aged 55-64

clear all
set more off
use "$maindir_replication${sep}$Data${sep}Nomenclatures${sep}participation_55_64_usa_fr.dta"

twoway (connected participation_fr year, msymbol(th)) (connected participation_us year, msymbol(O) msize(small)), title() subtitle() xlabel(1980(5)2020) xmtick(1980(1)2020) ylabel(30(10)70) ymtick(30(10)70) ytitle("") xtitle("") legend(order(1 "France" 2 "United States")) note() graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1B.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1B.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1B.png", as(png) replace


*Figure B1C: men
*Participation rate for men aged 25-64

clear all
set more off
use "$maindir_replication${sep}$Data${sep}Nomenclatures${sep}participation_usa_fr_men.dta"

twoway (connected participation_fr year, msymbol(th)) (connected participation_us year, msymbol(O) msize(small)), title() subtitle() xlabel(1980(5)2020) xmtick(1980(1)2020) ymtick(82(2)92) ytitle("") xtitle("") legend(order(1 "France" 2 "United States")) note() graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1C.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1C.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1C.png", as(png) replace


*Figure B1D: women
*Participation rate for women aged 25-64

clear all
set more off
use "$maindir_replication${sep}$Data${sep}Nomenclatures${sep}participation_usa_fr_women.dta"

twoway (connected participation_fr year, msymbol(th)) (connected participation_us year, msymbol(O) msize(small)), title() subtitle() xlabel(1980(5)2020) xmtick(1980(1)2020) ylabel(60(5)75) ytitle("") xtitle("") legend(order(1 "France" 2 "United States")) note() graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1D.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1D.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureB1D.png", as(png) replace

}
*


****************
***Gender Gap***
****************

*Figure C2

{
clear all
set more off
import delimited "$maindir_replication${sep}Part_A${sep}out${sep}$desc_stats${sep}L_CS_labor_yrgender_sum_stats.csv"

keep year male p50labor meanlabor
gen l_meanlabor = log(meanlabor)
gen l_p50labor = log(p50labor)

reshape wide p50labor meanlabor l_p50labor l_meanlabor, i(year) j(male)

gen gap_p50 = l_p50labor1 - l_p50labor0
gen gap_mean = l_meanlabor1 - l_meanlabor0

twoway connected gap_mean gap_p50 year, msymbol(O S) lcolor(blue red) lpattern(solid dash) mfcolor(blue*0.25 red*0.25) mlcolor(blue red) ylabel(.15(.05)0.4) xlabel(1991(3)2016) xtitle("") legend(order(1 "Mean Earnings" 2 "Median Earnings")) graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureC2_unconditional_gender_gap.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureC2_unconditional_gender_gap.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureC2_unconditional_gender_gap.png", as(png) replace

*
save "$maindir_replication${sep}Part_A${sep}dta${sep}unconditional_gender_gap.dta", replace

}
*

*************************
***Hours & Hourly wage***
*************************

*Figures D1-D3

{

*Figure D1
*Hours relative to full time workers (39h * 52 = 2028)

foreach subgp in all male fem {
	
	clear all
	set more off
	
	if "`subgp'" == "all"{
		use "$maindir_replication${sep}Part_A${sep}dta${sep}hours_percentiles_logearn_all"
		local labname = "All"
	}
	if "`subgp'" == "male"{
		use "$maindir_replication${sep}Part_A${sep}dta${sep}hours_percentiles_logearn_male"
		local labname = "Men"
	}
		
	if "`subgp'" == "fem"{
		use "$maindir_replication${sep}Part_A${sep}dta${sep}hours_percentiles_logearn_female"
		local labname = "Women"
	}
	
	*
	qui do "$maindir_replication${sep}Part_A${sep}do${sep}0_Initialize.do"
	qui do "$maindir_replication${sep}Part_A${sep}do${sep}myplots.do"		
	*

	foreach var in med mean {
		gen p5_h_`var' = 100*`var'_hours/2028 if percentile==1
		gen p10_h_`var' = 100*`var'_hours/2028 if percentile==2
		gen p25_h_`var' = 100*`var'_hours/2028 if percentile==3
		gen p50_h_`var' = 100*`var'_hours/2028 if percentile==4
		gen p75_h_`var' = 100*`var'_hours/2028 if percentile==5
		gen p90_h_`var' = 100*`var'_hours/2028 if percentile==6
		gen p95_h_`var' = 100*`var'_hours/2028 if percentile==7
		gen p99_h_`var' = 100*`var'_hours/2028 if percentile==8
	}

	*

	gen rece = inlist(year,${receyears})

	***

	// Define some common charactristics of the plots 
	global xtitlesize =   "medium" 
	global ytitlesize =   "medium" 
	global titlesize  =   "large" 
	global subtitlesize = "medium" 
	global formatfile  =  "pdf"
	global fontface   =   "Times New Roman"
	global marksize =     "medium"	


	***Levels***
	tspltAREALimPA "p90_h_med p75_h_med p50_h_med p25_h_med p10_h_med" /// Which variables?
	   "year" ///
	   1993 2016 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
		"Hours relative to a full time worker in 1993 (%)" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   ""	/// Figure name
	   "0" "110" "10"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 
	
	graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}FigureD1_`labname'.pdf", as(pdf) replace
	graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}FigureD1_`labname'.gph", replace
	
}
*

*Figure D2
*Hourly wage relative to minimum hourly wage

foreach subgp in all male fem {
	
	clear all
	set more off

	if "`subgp'" == "all"{
		use "$maindir_replication${sep}Part_A${sep}dta${sep}hours_percentiles_logearn_all"
		local labname = "All"
	}
	if "`subgp'" == "male"{
		use "$maindir_replication${sep}Part_A${sep}dta${sep}hours_percentiles_logearn_male"
		local labname = "Men"
	}
		
	if "`subgp'" == "fem"{
		use "$maindir_replication${sep}Part_A${sep}dta${sep}hours_percentiles_logearn_female"
		local labname = "Women"
	}
	
	*
	qui do "$maindir_replication${sep}Part_A${sep}do${sep}0_Initialize.do"
	qui do "$maindir_replication${sep}Part_A${sep}do${sep}myplots.do"		
	*

	*Hours
	foreach var in med mean {
		gen p5_h_`var' = log(`var'_hours) if percentile==1
		gen p10_h_`var' = log(`var'_hours) if percentile==2
		gen p25_h_`var' = log(`var'_hours) if percentile==3
		gen p50_h_`var' = log(`var'_hours) if percentile==4
		gen p75_h_`var' = log(`var'_hours) if percentile==5
		gen p90_h_`var' = log(`var'_hours) if percentile==6
		gen p95_h_`var' = log(`var'_hours) if percentile==7
		gen p99_h_`var' = log(`var'_hours) if percentile==8
	}
	*Wage
	foreach var in med mean {
		gen p5_w_`var' = `var'_inc if percentile==1
		gen p10_w_`var' = `var'_inc if percentile==2
		gen p25_w_`var' = `var'_inc if percentile==3
		gen p50_w_`var' = `var'_inc if percentile==4
		gen p75_w_`var' = `var'_inc if percentile==5
		gen p90_w_`var' = `var'_inc if percentile==6
		gen p95_w_`var' = `var'_inc if percentile==7
		gen p99_w_`var' = `var'_inc if percentile==8
	}

	*Hourly wage
	foreach var in med mean {
		gen p5_hw_`var' = p5_w_`var' - p5_h_`var'
		gen p10_hw_`var' = p10_w_`var' - p10_h_`var'
		gen p25_hw_`var' = p25_w_`var' - p25_h_`var'
		gen p50_hw_`var' = p50_w_`var' - p50_h_`var'
		gen p75_hw_`var' = p75_w_`var' - p75_h_`var'
		gen p90_hw_`var' = p90_w_`var' - p90_h_`var'
		gen p95_hw_`var' = p95_w_`var' - p95_h_`var'
		gen p99_hw_`var' = p99_w_`var' - p99_h_`var'
	}

	*
	
	local yinic = ${yrfirst} - 1991 + 1	
	local yend = ${yrlast} - 1991 + 1
	matrix smic_C = minwg_C[`yinic'..`yend',1]	
	
	matrix smicmat = J(${yrlast}-${yrfirst}+1,1,0)
	local tnum = ${yrlast}-${yrfirst}+1
	forvalue i = 1(1)`tnum' {
		matrix smicmat[`i',1] = smic_C[`i',1]/cpimat[`i',1]			
	}
	
	
	forvalue yr=1993/2016{
		local smic_index = `yr'-${yrfirst}+1
		foreach var in p5_hw_med p10_hw_med p25_hw_med p50_hw_med p75_hw_med p90_hw_med p95_hw_med p99_hw_med {
			if "`yr'"=="1993" {
			gen `var'_smic = .
			replace `var'_smic = exp(`var') / smicmat[`smic_index',1] if year==`yr'		//Coverting to real values
			}
			if "`yr'"!="1993" {
			replace `var'_smic = exp(`var') / smicmat[`smic_index',1] if year==`yr'
			}
		}
	}
	
	gen rece = inlist(year,${receyears})

	***

	// Define some common charactristics of the plots 
	global xtitlesize =   "medium" 
	global ytitlesize =   "medium" 
	global titlesize  =   "large" 
	global subtitlesize = "medium" 
	global formatfile  =  "pdf"
	global fontface   =   "Times New Roman"
	global marksize =     "medium"	


	***Levels***

	tw connected (p99_hw_med_smic p90_hw_med_smic p75_hw_med_smic p50_hw_med_smic p25_hw_med_smic p10_hw_med_smic) year, xlabel(1993(3)2016) legend(order(1 "p99" 2 "p90" 3 "p75" 4 "p50" 5 "p25" 6 "p10") c(1) ring(0) position(11) region(color(none) lcolor(white))) graphregion(color(white)) ytitle("Relative to minimum hourly wage") ylabel(0(1)8) xtitle("") title("") subtitle("") lcolor(gray blue green red navy black) lpattern(solid dash_dot dash longdash solid shortdash) msymbol(T O + S x D) lwidth(medthick) mfcolor(gray*0.25 blue*0.25 green*0.25 red*0.25 navy*0.25 black*0.25) mlcolor(gray blue green red navy black) graphregion(color(white))

	graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}FigureD2_`labname'.pdf", as(pdf) replace
	graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}FigureD2_`labname'.gph", replace
		
}
*


*Figure D3
*Hours & Hourly wage

foreach subgp in all male fem {
	
	clear all
	set more off

	cd "$data"
	
	if "`subgp'" == "all"{
		use "$maindir_replication${sep}Part_A${sep}dta${sep}hours_percentiles_logearn_all"
		local labname = "All"
	}
	if "`subgp'" == "male"{
		use "$maindir_replication${sep}Part_A${sep}dta${sep}hours_percentiles_logearn_male"
		local labname = "Men"
	}
		
	if "`subgp'" == "fem"{
		use "$maindir_replication${sep}Part_A${sep}dta${sep}hours_percentiles_logearn_female"
		local labname = "Women"
	}
	
	*
	qui do "$maindir_replication${sep}Part_A${sep}do${sep}0_Initialize.do"
	qui do "$maindir_replication${sep}Part_A${sep}do${sep}myplots.do"		
	*

	*Hours
	foreach var in med mean {
		gen p5_h_`var' = log(`var'_hours) if percentile==1
		gen p10_h_`var' = log(`var'_hours) if percentile==2
		gen p25_h_`var' = log(`var'_hours) if percentile==3
		gen p50_h_`var' = log(`var'_hours) if percentile==4
		gen p75_h_`var' = log(`var'_hours) if percentile==5
		gen p90_h_`var' = log(`var'_hours) if percentile==6
		gen p95_h_`var' = log(`var'_hours) if percentile==7
		gen p99_h_`var' = log(`var'_hours) if percentile==8
	}
	*Wage
	foreach var in med mean {
		gen p5_w_`var' = `var'_inc if percentile==1
		gen p10_w_`var' = `var'_inc if percentile==2
		gen p25_w_`var' = `var'_inc if percentile==3
		gen p50_w_`var' = `var'_inc if percentile==4
		gen p75_w_`var' = `var'_inc if percentile==5
		gen p90_w_`var' = `var'_inc if percentile==6
		gen p95_w_`var' = `var'_inc if percentile==7
		gen p99_w_`var' = `var'_inc if percentile==8
	}

	*Hourly wage
	foreach var in med mean {
		gen p5_hw_`var' = p5_w_`var' - p5_h_`var'
		gen p10_hw_`var' = p10_w_`var' - p10_h_`var'
		gen p25_hw_`var' = p25_w_`var' - p25_h_`var'
		gen p50_hw_`var' = p50_w_`var' - p50_h_`var'
		gen p75_hw_`var' = p75_w_`var' - p75_h_`var'
		gen p90_hw_`var' = p90_w_`var' - p90_h_`var'
		gen p95_hw_`var' = p95_w_`var' - p95_h_`var'
		gen p99_hw_`var' = p99_w_`var' - p99_h_`var'
	}

	*

	gen rece = inlist(year,${receyears})

	*

	foreach var in med mean {
		
		local hourly_w = "p5_hw_`var' p10_hw_`var' p25_hw_`var' p50_hw_`var' p75_hw_`var' p90_hw_`var' p95_hw_`var' p99_hw_`var'"
		local wage = "p5_w_`var' p10_w_`var' p25_w_`var' p50_w_`var' p75_w_`var' p90_w_`var' p95_w_`var' p99_w_`var'"
		local hours = "p5_h_`var' p10_h_`var' p25_h_`var' p50_h_`var' p75_h_`var' p90_h_`var' p95_h_`var' p99_h_`var'"

		foreach vv in `hourly_w' `wage' `hours'  {
			sum  `vv' if year == 1993, meanonly
			gen n`vv' = `vv' - r(mean)
		}
	}
	*


	***

	// Define some common charactristics of the plots 
	global xtitlesize =   "medium" 
	global ytitlesize =   "medium" 
	global titlesize  =   "large" 
	global subtitlesize = "medium" 
	global formatfile  =  "pdf"
	global fontface   =   "Times New Roman"
	global marksize =     "medium"	



	***Replicate fig1_all_logearn***
	*The reference year is 1993 and not 1991
/*
	tspltAREALimPA "np90_w_med np75_w_med np50_w_med np25_w_med np10_w_med" /// Which variables?
	   "year" ///
	   1993 2016 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to 1993" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_`labname'_w_med"	/// Figure name
	   "-.3" ".4" ".1"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 
		
	graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}FigureD30_`labname'.pdf", as(pdf) replace
	graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}FigureD30_`labname'.gph", replace
*/

	***Hours***

	tspltAREALimPA "np90_h_med np75_h_med np50_h_med np25_h_med np10_h_med" /// Which variables?
	   "year" ///
	   1993 2016 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Hours Relative to 1993" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_`labname'_w_med"	/// Figure name
	   "-.3" ".3" ".1"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 

	graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}FigureD31_`labname'.pdf", as(pdf) replace
	graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}FigureD31_`labname'.gph", replace

	***Hourly wage***

	tspltAREALimPA "np90_hw_med np75_hw_med np50_hw_med np25_hw_med np10_hw_med" /// Which variables?
	   "year" ///
	   1993 2016 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "Hourly wage for Sample: `labname'" /// x axis title
	   "Percentiles Relative to 1993" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_`labname'_w_med"	/// Figure name
	   "-.3" ".4" ".1"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 

	graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}FigureD32_`labname'.pdf", as(pdf) replace
	graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}FigureD32_`labname'.gph", replace

	**
}
*

}
*


****************************
***Variance decomposition***
****************************

*Figure D4

{

clear all
use "$maindir_replication${sep}Part_A${sep}dta${sep}variance_decomposition_all"

cap drop y1 y2 y3
clonevar y1 = year
clonevar y2 = year
clonevar y3 = year

replace y1 = y1-.3
replace y2 = y2
replace y3 = y3+.3

graph twoway (bar v_l_total_hours y1 if year>=1995, barwidth(.3)) (bar v_l_wage y2 if year>=1995, barwidth(.3)) (bar cov_lhours_lwage y3 if year>=1995, barwidth(.3)), ylabel(-.10(.10).40) ymtick(-.10(.05).40) xtitle("") xlabel(1995(2)2015) xmtick(1995(1)2016) legend(order(1 "Var(log(h))" 2 "Var(log(w))" 3 "2 Cov(log(h),log(w))") c(3)) graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}decomposition_var_logearn_all.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}decomposition_var_logearn_all2.png", as(png) replace

**Men

clear all
set more off
use "$maindir_replication${sep}Part_A${sep}dta${sep}variance_decomposition_male"

cap drop y1 y2 y3
clonevar y1 = year
clonevar y2 = year
clonevar y3 = year

replace y1 = y1-.3
replace y2 = y2
replace y3 = y3+.3

graph twoway (bar v_l_total_hours y1 if year>=1995, barwidth(.3)) (bar v_l_wage y2 if year>=1995, barwidth(.3)) (bar cov_lhours_lwage y3 if year>=1995, barwidth(.3)), ylabel(-.10(.10).40) ymtick(-.10(.05).40) xtitle("") xlabel(1995(2)2015) xmtick(1995(1)2016) legend(order(1 "Var(log(h))" 2 "Var(log(w))" 3 "2 Cov(log(h),log(w))") c(3)) graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureD4A.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureD4A.png", as(png) replace


**Women

clear all
set more off
use "$maindir_replication${sep}Part_A${sep}dta${sep}variance_decomposition_female"

cap drop y1 y2 y3
clonevar y1 = year
clonevar y2 = year
clonevar y3 = year

replace y1 = y1-.3
replace y2 = y2
replace y3 = y3+.3

graph twoway (bar v_l_total_hours y1 if year>=1995, barwidth(.3)) (bar v_l_wage y2 if year>=1995, barwidth(.3)) (bar cov_lhours_lwage y3 if year>=1995, barwidth(.3)), ylabel(-.10(.10).40) ymtick(-.10(.05).40) xtitle("") xlabel(1995(2)2015) xmtick(1995(1)2016) legend(order(1 "Var(log(h))" 2 "Var(log(w))" 3 "2 Cov(log(h),log(w))") c(3)) graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureD4B.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureD4B.png", as(png) replace


}
*

***************************
***Rank-Rank regressions***
***************************


{
	
*Figure F3: permanent rank-rank correlation	(whole population)

{

clear all
set more off
use "$maindir_replication${sep}Part_A${sep}dta${sep}panel_social_mobility"

keep if year>=1993

*Five years

cap drop high_perm low_perm
gen high_perm = coef_perm_5 + 1.96*se_perm_5
gen low_perm = coef_perm_5 - 1.96*se_perm_5

tw (rcap high_perm low_perm year if n==1 & year<2012) (scatter coef_perm_5 year if n==1 & year<2012, mcolor(navy) msize(small)), graphregion(color(white)) xlabel(1993(2)2011) ylabel(.75(.05)0.90) xtitle("") ytitle("") leg(off)
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF3_permanent_earnings_5y.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF3_permanent_earnings_5y.png", as(png) replace


/*

***Robustness

*1 Year

cap drop high_perm low_perm
gen high_perm = coef_perm_5 + 1.96*se_perm_5
gen low_perm = coef_perm_5 - 1.96*se_perm_5

tw (rcap high_perm low_perm year if n==1 & year<2016) (scatter coef_perm_1 year if n==1 & year<2016, mcolor(navy) msize(small)), graphregion(color(white)) xlabel(1993(2)2015) ylabel(.75(.05)0.90) xtitle("") ytitle("") leg(off)
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF3_permanent_earnings_1y.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF3_permanent_earnings_1y.png", as(png) replace


***Residual earnings

*5 years

cap drop high_res low_res
gen high_res = coef_res_5 + 1.96*se_res_5
gen low_res = coef_res_5 - 1.96*se_res_5

tw (rcap high_res low_res year if n==1 & year<2012) (scatter coef_res_5 year if n==1 & year<2012, mcolor(navy) msize(small)), graphregion(color(white)) xlabel(1993(2)2011) ylabel(.65(.05)0.80) xtitle("") ytitle("") leg(off)
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF3_residual_earnings_5y.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF3_residual_earnings_5y.png", as(png) replace


*1 year

cap drop high_res low_res
gen high_res = coef_res_1 + 1.96*se_res_1
gen low_res = coef_res_1 - 1.96*se_res_1

tw (rcap high_res low_res year if n==1 & year<2015) (scatter coef_res_1 year if n==1 & year<2015, mcolor(navy) msize(small)), graphregion(color(white)) xlabel(1993(2)2011) ylabel(.80(.02)0.90) xtitle("") ytitle("") leg(off)
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF3_residual_earnings_1y.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF3_residual_earnings_1y.png", as(png) replace
*/

}
*

*Figure F3: permanent rank-rank correlation (by gender / by age)


*Age groups
{

*5 Year

foreach var in young mid old {
	cap drop high_`var' low_`var'
	gen high_`var' = coef_perm_5_`var' + 1.96*se_perm_5_`var'
	gen low_`var' = coef_perm_5_`var' - 1.96*se_perm_5_`var'
}
*

tw (rcap high_young low_young year if n==1 & year<2012) (scatter coef_perm_5_young year if n==1 & year<2012, mcolor(navy) msize(small)) ///
	(rcap high_mid low_mid year if n==1 & year<2012, lcolor(maroon)) (scatter coef_perm_5_mid year if n==1 & year<2012, mcolor(maroon) msymbol(+) msize(small)) ///
	(rcap high_old low_old year if n==1 & year<2012, lcolor(forest_green)) (scatter coef_perm_5_old year if n==1 & year<2012, mcolor(forest_green)  msymbol(D) msize(small)), ///
	graphregion(color(white)) xlabel(1993(2)2011) ylabel(.65(.05)0.90) xtitle("") ytitle("") legend(order(1 "25-34" 2 "" 3 "35-44" 4 "" 5 "45-55" 6 ""))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4A_permanent_earnings_5y_age.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4A_permanent_earnings_5y_age.png", as(png) replace


/*
*1 Year

foreach var in young mid old {
	cap drop high_`var' low_`var'
	gen high_`var' = coef_perm_1_`var' + 1.96*se_perm_1_`var'
	gen low_`var' = coef_perm_1_`var' - 1.96*se_perm_1_`var'
}
*

tw (rcap high_young low_young year if n==1 & year<2016) (scatter coef_perm_1_young year if n==1 & year<2016, mcolor(navy)) ///
	(rcap high_mid low_mid year if n==1 & year<2016, lcolor(maroon)) (scatter coef_perm_1_mid year if n==1 & year<2016, mcolor(maroon)) ///
	(rcap high_old low_old year if n==1 & year<2016, lcolor(forest_green)) (scatter coef_perm_1_old year if n==1 & year<2016, mcolor(forest_green)), ///
	graphregion(color(white)) xlabel(1993(2)2015) ylabel(.65(.05)0.90) xtitle("") ytitle("") legend(order(1 "25-34" 2 "" 3 "35-44" 4 "" 5 "45-55" 6 ""))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4A_permanent_earnings_1y_age.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4A_permanent_earnings_1y_age.png", as(png) replace


*Residual earnings

*5 Year

foreach var in young mid old {
	cap drop high_`var' low_`var'
	gen high_`var' = coef_res_5_`var' + 1.96*se_res_5_`var'
	gen low_`var' = coef_res_5_`var' - 1.96*se_res_5_`var'
}
*

tw (rcap high_young low_young year if n==1 & year<2012) (scatter coef_res_5_young year if n==1 & year<2012, mcolor(navy)) ///
	(rcap high_mid low_mid year if n==1 & year<2012, lcolor(maroon)) (scatter coef_res_5_mid year if n==1 & year<2012, mcolor(maroon)) ///
	(rcap high_old low_old year if n==1 & year<2012, lcolor(forest_green)) (scatter coef_res_5_old year if n==1 & year<2012, mcolor(forest_green)), ///
	graphregion(color(white)) xlabel(1993(2)2011) ylabel(.55(.1)0.85) ymtick(.55(.05)0.90) xtitle("") ytitle("Five-year rank-rank correlation coefficient") legend(order(1 "25-34" 2 "" 3 "35-44" 4 "" 5 "45-55" 6 ""))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4A_residual_earnings_5y_age.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4A_residual_earnings_5y_age.png", as(png) replace

*1 Year

foreach var in young mid old {
	cap drop high_`var' low_`var'
	gen high_`var' = coef_res_1_`var' + 1.96*se_res_1_`var'
	gen low_`var' = coef_res_1_`var' - 1.96*se_res_1_`var'
}
*

tw (rcap high_young low_young year if n==1 & year<2016) (scatter coef_res_1_young year if n==1 & year<2016, mcolor(navy)) ///
	(rcap high_mid low_mid year if n==1 & year<2016, lcolor(maroon)) (scatter coef_res_1_mid year if n==1 & year<2016, mcolor(maroon)) ///
	(rcap high_old low_old year if n==1 & year<2016, lcolor(forest_green)) (scatter coef_res_1_old year if n==1 & year<2016, mcolor(forest_green)), ///
	graphregion(color(white)) xlabel(1993(2)2015) ylabel(.70(.1)0.90) ymtick(.70(.05)0.95) xtitle("") ytitle("One-year rank-rank correlation coefficient") legend(order(1 "25-34" 2 "" 3 "35-44" 4 "" 5 "45-55" 6 ""))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4A_residual_earnings_5y_age.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4A_residual_earnings_5y_age.png", as(png) replace
}
*
*/

}
*


*Men and Women separately
{

*5 Year

cap drop high_m low_m high_f low_f
gen high_m = coef_perm_5_m + 1.96*se_perm_5_m
gen low_m = coef_perm_5_m - 1.96*se_perm_5_m
gen high_f = coef_perm_5_f + 1.96*se_perm_5_f
gen low_f = coef_perm_5_f - 1.96*se_perm_5_f


tw (rcap high_m low_m year if n==1 & year<2012) (scatter coef_perm_5_m year if n==1 & year<2012, mcolor(navy) msymbol(+) msize(small)) ///
	(rcap high_f low_f year if n==1 & year<2012, lcolor(maroon)) (scatter coef_perm_5_f year if n==1 & year<2012, mcolor(maroon) msize(small)), ///
	graphregion(color(white)) xlabel(1993(2)2011) ylabel(.70(.05)0.90) xtitle("") ytitle("") legend(order(1 "Men" 2 "" 3 "Women" 4 ""))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4B_permanent_earnings_5y_gender.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4B_permanent_earnings_5y_gender.png", as(png) replace


/*
***Robustness

*1 Year

cap drop high_m low_m high_f low_f
gen high_m = coef_perm_5_m + 1.96*se_perm_5_m
gen low_m = coef_perm_5_m - 1.96*se_perm_5_m
gen high_f = coef_perm_5_f + 1.96*se_perm_5_f
gen low_f = coef_perm_5_f - 1.96*se_perm_5_f


tw (rcap high_m low_m year if n==1 & year<2016) (scatter coef_perm_5_m year if n==1 & year<2016, mcolor(navy) msize(small)) ///
	(rcap high_f low_f year if n==1 & year<2016, lcolor(maroon)) (scatter coef_perm_5_f year if n==1 & year<2016, mcolor(maroon)), ///
	graphregion(color(white)) xlabel(1993(2)2015) ylabel(.70(.05)0.90) xtitle("") ytitle("") legend(order(1 "Men" 2 "" 3 "Women" 4 ""))

graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4B_permanent_earnings_5y_gender.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4B_permanent_earnings_5y_gender.png", as(png) replace

*Residual

*5 Year

cap drop high_m low_m high_f low_f
gen high_m = coef_res_5_m + 1.96*se_res_5_m
gen low_m = coef_res_5_m - 1.96*se_res_5_m
gen high_f = coef_res_5_f + 1.96*se_res_5_f
gen low_f = coef_res_5_f - 1.96*se_res_5_f


tw (rcap high_m low_m year if n==1 & year<2012) (scatter coef_res_5_m year if n==1 & year<2012, mcolor(navy) msize(small)) ///
	(rcap high_f low_f year if n==1 & year<2012, lcolor(maroon)) (scatter coef_res_5_f year if n==1 & year<2012, mcolor(maroon)), ///
	graphregion(color(white)) xlabel(1993(2)2011) ylabel(.60(.05)0.80) xtitle("") ytitle("") legend(order(1 "Men" 2 "" 3 "Women" 4 ""))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4B_residual_earnings_5y_gender.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4B_residual_earnings_5y_gender.png", as(png) replace


*1 Year

cap drop high_m low_m high_f low_f
gen high_m = coef_res_1_m + 1.96*se_res_1_m
gen low_m = coef_res_1_m - 1.96*se_res_1_m
gen high_f = coef_res_1_f + 1.96*se_res_1_f
gen low_f = coef_res_1_f - 1.96*se_res_1_f


tw (rcap high_m low_m year if n==1 & year<2016) (scatter coef_res_1_m year if n==1 & year<2016, mcolor(navy) msize(small)) ///
	(rcap high_f low_f year if n==1 & year<2016, lcolor(maroon)) (scatter coef_res_1_f year if n==1 & year<2016, mcolor(maroon)), ///
	graphregion(color(white)) xlabel(1993(2)2015) ylabel(.75(.05)0.90) xtitle("") ytitle("One-year rank-rank correlation coefficient") legend(order(1 "Men" 2 "" 3 "Women" 4 ""))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4B_residual_earnings_1y_gender.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF4B_residual_earnings_1y_gender.png", as(png) replace
}
*
*/
}
*

*Figure F5

*Territories
{
*5 Year

sort n year
tw connected (coef_perm_5_P coef_perm_5_C coef_perm_5_B coef_perm_5_I coef_perm_5_R) year if n==1 & year<2012, graphregion(color(white)) xlabel(1993(2)2011) ylabel(.70(.05)0.90) xtitle("") ytitle("") legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas")) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF5_permanent_earnings_5y_territories.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF5_permanent_earnings_5y_territories.png", as(png) replace


/*

***Robustness

*1 Year

sort n year
tw connected (coef_perm_1_P coef_perm_1_C coef_perm_1_B coef_perm_1_I coef_perm_1_R) year if n==1 & year<2016, graphregion(color(white)) xlabel(1993(2)2015) ylabel(.70(.05)0.90) xtitle("") ytitle("") legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas")) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF5_permanent_earnings_1y_territories.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF5_permanent_earnings_1y_territories.png", as(png) replace

**Residucal earnings

*5 year

sort n year
tw connected (coef_res_5_P coef_res_5_C coef_res_5_B coef_res_5_I coef_res_5_R) year if n==1 & year<2012, graphregion(color(white)) xlabel(1993(2)2011) ylabel(.60(.05)0.80) xtitle("") ytitle("Five-year rank-rank correlation coefficient") legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas")) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF5_residual_earnings_5y_territories.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF5_residual_earnings_5y_territories.png", as(png) replace

*1 Year

sort n year
tw connected (coef_res_1_P coef_res_1_C coef_res_1_B coef_res_1_I coef_res_1_R) year if n==1 & year<2016, graphregion(color(white)) xlabel(1993(2)2015) ylabel(.75(.05)0.90) xtitle("") ytitle("One-year rank-rank correlation coefficient") legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas")) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF5_residual_earnings_1y_territories.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs${sep}figureF5_residual_earnings_1y_territories.png", as(png) replace
*/

}
*

}
*
