

**********
***Data***
**********

**Table B1
*Share of workers below several (minimum) thresholds of earnings

{
clear all
set more off

use "$maindir_replication${sep}Part_A${sep}dta${sep}master_sample.dta"

drop researn*
drop arcearn*
drop logearnc*
drop permearn*
*

global cpi2018 = 100		// Set the value of the CPI in 2018. 
matrix cpimat = /*  CPI between ${yrfirst}  and ${yrlast}
*/ (67.6747347, 69.29892833, 70.75420582, 71.88627312, 73.18022603, 74.64383055, 75.53955652, 75.99279386, 76.37275783, 77.67109471, /*
*/	78.91383223, 80.41319504, 82.10187214, 83.82601145, 85.25105365, 86.70032156, 88.00082638, 90.46484952, 90.55531437, 91.91364408, /*
*/  93.84383061, 95.72070722, 96.58219359, 97.06510456, 97.06510456, 97.25923476, 98.23182711, 100)'

matrix cpimat = cpimat/${cpi2018}

*

matrix minwg_C = /* Nominal minimum wage 1991-2018 in France
*/ (4.815102209, 5.099673708, 5.193938017, 5.365443162, 5.529325855,/*
*/  5.717600391, 5.88072084, 6.071282111, 6.169611728, 6.306815843,/*
*/  6.535489369, 6.75, 7.01, 7.4, 7.82, /*
*/  8.15, 8.355, 8.58, 8.725, 8.86, /*
*/  9.015833333, 9.31, 9.43, 9.53, 9.61, /*
*/  9.67, 9.76, 9.88)'

global yrfirst = 1991 
global yrlast =  2016

local yinic = ${yrfirst} - 1991 + 1	
local yend = ${yrlast} - 1991 + 1

matrix mininc_C1 = 200*minwg_C[`yinic'..`yend',1]
matrix mininc_C2 = 300*minwg_C[`yinic'..`yend',1]
matrix mininc_C3 = 260*minwg_C[`yinic'..`yend',1]

matrix rmininc1 = J(${yrlast}-${yrfirst}+1,1,0)
matrix rmininc2 = J(${yrlast}-${yrfirst}+1,1,0)
matrix rmininc3 = J(${yrlast}-${yrfirst}+1,1,0)

local i = 1
local tnum = ${yrlast}-${yrfirst}+1
forvalues pp = 1(1)`tnum'{
	matrix rmininc1[`i',1] = mininc_C1[`i',1]/cpimat[`i',1]
	matrix rmininc2[`i',1] = mininc_C2[`i',1]/cpimat[`i',1]
	matrix rmininc3[`i',1] = mininc_C3[`i',1]/cpimat[`i',1]
	
	local i = `i' + 1
}

*

forvalues yr = $yrfirst/$yrlast{	
	gen logearn`yr'_1 = log(labor`yr') if labor`yr'>=rmininc1[`yr'-${yrfirst}+1,1] & labor`yr'!=. 
	gen logearn`yr'_2 = log(labor`yr') if labor`yr'>=rmininc2[`yr'-${yrfirst}+1,1] & labor`yr'!=. 
	gen baseline_threshold`yr' = rmininc3[`yr'-${yrfirst}+1,1]
}
*

forvalue yr = 1991/2016 {

	gen below_threshold_`yr' = 0 if labor`yr'!=.
	replace below_threshold_`yr' = 1 if logearn`yr'==. & labor`yr'!=.

	gen below_threshold1_`yr' = 0 if labor`yr'!=.
	replace below_threshold1_`yr' = 1 if logearn`yr'_1==. & labor`yr'!=.

	gen below_threshold2_`yr' = 0 if labor`yr'!=.
	replace below_threshold2_`yr' = 1 if logearn`yr'_2==. & labor`yr'!=.

}
*

global threshold = "below_threshold_1991 below_threshold_1992 below_threshold_1993 below_threshold_1994 below_threshold_1995 below_threshold_1996 below_threshold_1997 below_threshold_1998 below_threshold_1999 below_threshold_2000 below_threshold_2001 below_threshold_2002 below_threshold_2003 below_threshold_2004 below_threshold_2005 below_threshold_2006 below_threshold_2007 below_threshold_2008 below_threshold_2009 below_threshold_2010 below_threshold_2011 below_threshold_2012 below_threshold_2013 below_threshold_2014 below_threshold_2015 below_threshold_2016"
global threshold2 = "below_threshold1_1991 below_threshold2_1991 below_threshold1_1992 below_threshold2_1992 below_threshold1_1993 below_threshold2_1993 below_threshold1_1994 below_threshold2_1994 below_threshold1_1995 below_threshold2_1995 below_threshold1_1996 below_threshold2_1996 below_threshold1_1997 below_threshold2_1997 below_threshold1_1998 below_threshold2_1998 below_threshold1_1999 below_threshold2_1999 below_threshold1_2000 below_threshold2_2000 below_threshold1_2001 below_threshold2_2001 below_threshold1_2002 below_threshold2_2002 below_threshold1_2003 below_threshold2_2003 below_threshold1_2004 below_threshold2_2004 below_threshold1_2005 below_threshold2_2005 below_threshold1_2006 below_threshold2_2006 below_threshold1_2007 below_threshold2_2007 below_threshold1_2008 below_threshold2_2008 below_threshold1_2009 below_threshold2_2009 below_threshold1_2010 below_threshold2_2010 below_threshold1_2011 below_threshold2_2011 below_threshold1_2012 below_threshold2_2012 below_threshold1_2013 below_threshold2_2013 below_threshold1_2014 below_threshold2_2014 below_threshold1_2015 below_threshold2_2015 below_threshold1_2016 below_threshold2_2016"
global threshold3 = "baseline_threshold1991 baseline_threshold1992 baseline_threshold1993 baseline_threshold1994 baseline_threshold1995 baseline_threshold1996 baseline_threshold1997 baseline_threshold1998 baseline_threshold1999 baseline_threshold2000 baseline_threshold2001 baseline_threshold2002 baseline_threshold2003 baseline_threshold2004 baseline_threshold2005 baseline_threshold2006 baseline_threshold2007 baseline_threshold2008 baseline_threshold2009 baseline_threshold2010 baseline_threshold2011 baseline_threshold2012 baseline_threshold2013 baseline_threshold2014 baseline_threshold2015 baseline_threshold2016"

collapse (mean) $threshold $threshold2 $threshold3

*
gen id=1
reshape long below_threshold_ below_threshold1_ below_threshold2_ baseline_threshold, i(id) j(year)
drop id
*

replace below_threshold_ = 100 * below_threshold_
replace below_threshold1_ = 100 * below_threshold1_
replace below_threshold2_ = 100 * below_threshold2_

rename below_threshold_ below_threshold
rename below_threshold1_ below_threshold1
rename below_threshold2_ below_threshold2

save "$maindir_replication${sep}Part_A${sep}dta${sep}income_thresholds_panel.dta",replace

*Table B.1 : Value of the minimum threshold

keep year baseline_threshold
replace baseline_threshold = round(baseline_threshold)
xpose, clear varname
order _varname
rename _varname varname

save "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}tableB1_income_thresholds_panel.dta", replace

}
*

**Tables B2 & B3
*Descriptive statistics

{

*Tables B.2: earnings distribution by gender

{
*Percentiles all

clear all
set more off
import delimited "$maindir_replication${sep}Part_A${sep}out${sep}${desc_stats}${sep}L_CS_labor_yr_sum_stats.csv"
keep if inlist(year,1995,2005,2015)
keep year p1labor p5labor p10labor p25labor p50labor p75labor p90labor p95labor p99labor p99_9labor
foreach var in p1labor p5labor p10labor p25labor p50labor p75labor p90labor p95labor p99labor p99_9labor {
	replace `var' = round(`var')
}
*
save "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}tableB2A_percentiles_laborearn_all.dta", replace


*Percentiles men

clear all
set more off
import delimited "$maindir_replication${sep}Part_A${sep}out${sep}${desc_stats}${sep}L_CS_labor_yrgender_sum_stats.csv"
keep if inlist(year,1995,2005,2015)
keep if male==1
keep year p1labor p5labor p10labor p25labor p50labor p75labor p90labor p95labor p99labor p99_9labor
foreach var in p1labor p5labor p10labor p25labor p50labor p75labor p90labor p95labor p99labor p99_9labor {
	replace `var' = round(`var')
}
*
save "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}tableB2B_percentiles_laborearn_male.dta", replace

*Percentiles women

clear all
set more off
import delimited "$maindir_replication${sep}Part_A${sep}out${sep}${desc_stats}${sep}L_CS_labor_yrgender_sum_stats.csv"
keep if inlist(year,1995,2005,2015)
keep if male==0
keep year p1labor p5labor p10labor p25labor p50labor p75labor p90labor p95labor p99labor p99_9labor
foreach var in p1labor p5labor p10labor p25labor p50labor p75labor p90labor p95labor p99labor p99_9labor {
	replace `var' = round(`var')
}
*
save "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}tableB2C_percentiles_laborearn_female.dta", replace


}
*

*Table B.3: descriptive statistics baseline sample

{
*number of observations
clear all
set more off
import delimited "$maindir_replication${sep}Part_A${sep}out${sep}${desc_stats}${sep}L_CS_labor_yr_sum_stats.csv"
keep if inlist(year,1995,2015)
keep year nlabor
rename nlabor obs
replace obs = round(obs/1000000, .01)
save "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp1.dta", replace
*mean wage by gender
clear all
set more off
import delimited "$maindir_replication${sep}Part_A${sep}out${sep}${desc_stats}${sep}L_CS_labor_yrgender_sum_stats.csv"
keep if inlist(year,1995,2015)
keep year male meanlabor
reshape wide meanlabor, i(year) j(male)
rename meanlabor0 meanlabor_women
rename meanlabor1 meanlabor_men
foreach var in meanlabor_women meanlabor_men {
	replace `var' = round(`var')
}
save "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp2.dta", replace
*share of women
clear all
set more off
import delimited "$maindir_replication${sep}Part_A${sep}out${sep}${desc_stats}${sep}L_CS_labor_yrgender_sum_stats.csv"
keep if inlist(year,1995,2015)
collapse (mean) male [fw=nlabor], by(year)
gen share_women = 1 - male
drop male
replace share_women = 100 * round(share_women, .001)
save "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp3.dta", replace
*age & education groups (shares)
clear all
set more off
import delimited "$maindir_replication${sep}Part_A${sep}out${sep}${desc_stats}${sep}CS_cross_tabulation.csv"
keep if inlist(year,1995,2015)
gen age_25_35 = numobs if age>=25 & age<=35
gen age_36_45 = numobs if age>=36 & age<=45
gen age_46_55 = numobs if age>=46 & age<=55
gen obs_educ = numobs if educ!=.
gen less_hs = numobs if educ==1
gen hs = numobs if educ==2
gen some_college = numobs if educ==3
gen advanced_college = numobs if educ==4
collapse (sum) age_25_35 age_36_45 age_46_55 less_hs hs some_college advanced_college numobs obs_educ ,by(year)
foreach var in age_25_35 age_36_45 age_46_55 {
	replace `var' = round(100 * `var' / numobs , 0.1)
}
foreach var in less_hs hs some_college advanced_college {
	replace `var' = round(100 * `var' / obs_educ , 0.1)
}
keep year age_25_35 age_36_45 age_46_55 less_hs hs some_college advanced_college
save "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp4.dta", replace
*
clear all
use "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp1.dta"
merge 1:1 year using "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp2.dta"
drop _merge
merge 1:1 year using "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp3.dta"
drop _merge
merge 1:1 year using "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp4.dta"
drop _merge
save "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}tableB3_descriptive_stats_sample.dta", replace

erase "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp1.dta"
erase "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp2.dta"
erase "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp3.dta"
erase "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}temp4.dta"
}
*
}
*

*************
***Figures***
*************

**Figure B.2
*Share of workers below the income threshold

{

*Baseline sample

clear all
set more off

use "$maindir_replication${sep}Part_A${sep}dta${sep}income_thresholds_panel.dta"

tw (line below_threshold year), title("") ytitle("Share (in %)") ylabel(0(2)10) ymtick(0(1)10) xtitle("") xlabel(1991(2)2016) graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}figureB2_share_below_threshold_panel.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}figureB2_share_below_threshold_panel.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}figureB2_share_below_threshold_panel.png", as(png) replace


*Robustness
/*
tw connected (below_threshold1 below_threshold below_threshold2 year), msymbol(D X S) msize(small small small) title("Share of observations below the MW thresholds") ytitle("Share (in %)") ylabel(0(2)10) ymtick(0(1)10) xtitle("") xlabel(1991(2)2016) legend(order(1 "200 hours" 2 "Baseline (260h)" 3 "300 hours") c(3)) graphregion(color(white))
graph save Graph "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}robustness_share_below_thresholds_panel.gph", replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}robustness_share_below_thresholds_panel.eps", as(eps) preview(off) replace
graph export "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats${sep}robustness_share_below_thresholds_panel.png", as(png) replace

sum below_threshold*
*200h: on average 1 point below (exclude 5.5% of the data against 6.5%)
*300h: on average .7 point above (exclude 7.2% of the data against 6.5%)
*/

}
*
