

************************************
***Between Urban Areas Inequality***
************************************

***Figure 14

{
clear all
set more off
use "$maindir_replication${sep}Part_B${sep}dta${sep}wage_panel_edp_2001_2016"


**Figure 14
*Between-Urban Areas Inequality

foreach yr in 2001 2015 {
	binscatter (n_p10_1 n_p25_1 n_p50_1 n_p75_1 n_p90_1 n_p99_1) rank if code_au2010!="001" & year_mean==`yr', line(connect) n(20) title("") subtitle("") ytitle("(0==Paris)") ylabel(0.(.2)-1) ymtick(0.1(.1)-1) xtitle("Rank based on population in 2015") legend(order (1 "p10" 2 "p25" 3 "p50" 4 "p75" 5 "p90" 6 "p99") c(3)) lcolor(black navy red green blue gray) msymbol(D x S + O T) mcolor(black navy red green blue gray)
	graph save Graph "$maindir${sep}figs${sep}figure14_`yr'.gph", replace
	graph export "$maindir${sep}figs${sep}figure14_`yr'.png", as(png) replace
}
*

**Figure H1
*Between-Urban Areas Inequality (residualized)

*2001
foreach var in 25 50 75 90 {
	binscatter (n_p`var'_1 n_p`var'_2 n_p`var'_3 n_p`var'_4) rank if code_au2010!="001" & year_mean==2001, med line(connect) n(20) title("") ytitle("P`var' (0==Paris)") ylabel(0(.2)-.6) ymtick(0(0.05)-.6) xtitle("") legend(order(1 "No controls" 2 "Sexe + Age + Diploma" 3 "+ Hours & Occ." 4 "+ Industry & Firm size")) graphregion(color(white)) lcolor(navy red green black) msymbol(D X S T) mcolor(navy red green black)
	graph save Graph "$maindir${sep}figs${sep}figureH1_2001_p`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureH1_2001_p`var'.png", as(png) replace
}
*

*2015
foreach var in 25 50 75 90 {
	binscatter (n_p`var'_1 n_p`var'_2 n_p`var'_3 n_p`var'_4) rank if code_au2010!="001" & year_mean==2015, med line(connect) n(20) title("") ytitle("P`var' (0==Paris)") ylabel(0(.2)-.6) ymtick(0(0.05)-.6) xtitle("") legend(order(1 "No controls" 2 "Sexe + Age + Diploma" 3 "+ Hours & Occ." 4 "+ Industry & Firm size")) graphregion(color(white)) lcolor(navy red green black) msymbol(D X S T) mcolor(navy red green black)
	graph save Graph "$maindir${sep}figs${sep}figureH1_2015_p`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureH1_2015_p`var'.png", as(png) replace
}
*

***Table H1
*Squared deviation from Paris
***Compute deviation from Paris for each percentile for the 2 periods

foreach var in p10_1 p25_1 p50_1 p75_1 p90_1 p95_1 p99_1 {
	gen d_`var' = n_`var'
	gen d2_`var' = n_`var'^2
}
*

collapse (sum) d_p10_1 d2_p10_1 d_p25_1 d2_p25_1 d_p50_1 d2_p50_1 d_p75_1 d2_p75_1 d_p90_1 d2_p90_1 d_p95_1 d2_p95_1 d_p99_1 d2_p99_1, by(year_mean)

keep year_mean d2_p10_1 d2_p25_1 d2_p50_1 d2_p75_1 d2_p90_1 d2_p95_1 d2_p99_1

sort year_mean
rename year_mean year
save "$maindir${sep}dta${sep}tableH1_sq_deviation_Paris.dta", replace

}
*

*****************
***Convergence***
*****************

***Figure 15

{

clear all
set more off
use "$maindir_replication${sep}Part_B${sep}dta${sep}convergence"


**Figure 15 A
*Median wage

{

forvalue yr=1995(5)2010 {
	local yrp = `yr' + 5

	_pctile p50_growth_`yr'_`yrp', p(1, 99)
	gen keep = 1 if (p50_growth_`yr'_`yrp'>r(r1) & p50_growth_`yr'_`yrp'<r(r2))
	
	qui: reg p50_growth_`yr'_`yrp' l_p50_`yr' if keep == 1, r
	global slope : di %4.2f _b[l_p50_`yr']
	global se: di  %4.2f _se[l_p50_`yr']

	twoway (scatter p50_growth_`yr'_`yrp' l_p50_`yr' if keep==1) (lfit p50_growth_`yr'_`yrp' l_p50_`yr' if keep==1), legend(off) title("`yr'-`yrp'") subtitle("Slope: ${slope} ; SE: ${se}") ytitle("Annual Income Growth Rate (in%)") xtitle("Log of p50 labor earnings, `yr'") ylabel(-4(2)6) ymtick(-4(.5)6.5) xlabel(9.4(0.2)10.4) graphregion(color(white))
	graph save Graph "$maindir${sep}figs${sep}figure15A_`yr'.gph", replace
	graph export "$maindir${sep}figs${sep}figure15A_`yr'.png", as(png) replace
	
	drop keep
}
*

graph combine "$maindir${sep}figs${sep}figure15A_1995" "$maindir${sep}figs${sep}figure15A_2000" "$maindir${sep}figs${sep}figure15A_2005" "$maindir${sep}figs${sep}figure15A_2010", col(2) title("") graphregion(color(white)) note("")
graph save Graph "$maindir${sep}figs${sep}figure15A.gph", replace
graph export "$maindir${sep}figs${sep}figure15A.png", as(png) replace

foreach var in png gph {
	erase "$maindir${sep}figs${sep}figure15A_1995.`var'" 
	erase "$maindir${sep}figs${sep}figure15A_2000.`var'"
	erase "$maindir${sep}figs${sep}figure15A_2005.`var'"
	erase "$maindir${sep}figs${sep}figure15A_2010.`var'"
}
*

**Figure I1 A
*Using size instead of initial wage

_pctile p50_growth_1995_2015, p(1, 99)
gen keep = 1 if (p50_growth_1995_2015>r(r1) & p50_growth_1995_2015<r(r2))

qui: reg p50_growth_1995_2015 rank if keep == 1, r
global slope : di %4.3f 100*_b[rank]
global se: di  %4.3f 100*_se[rank]

twoway (scatter p50_growth_1995_2015 rank if keep==1) (lfit p50_growth_1995_2015 rank if keep==1), legend(off) title("") subtitle("Slope: ${slope} x 10{superscript:-2} ; SE: ${se} x 10{superscript:-2}") ytitle("Annual Income Growth Rate (in%)") xtitle("Rank based on population in 2015") ylabel(-2(1)3) ymtick(-2(0.5)3) xlabel() graphregion(color(white))
graph save Graph "$maindir${sep}figs${sep}figureI1_A.gph", replace
graph export "$maindir${sep}figs${sep}figureI1_A.png", as(png) replace

drop keep

}
*

**Figure 15 B
*Mean wage

{

forvalue yr=1995(5)2010 {
	local yrp = `yr' + 5

	_pctile mean_growth_`yr'_`yrp', p(1, 99)
	gen keep = 1 if (mean_growth_`yr'_`yrp'>r(r1) & mean_growth_`yr'_`yrp'<r(r2))
	
	qui: reg mean_growth_`yr'_`yrp' l_mean_`yr' if keep == 1, r
	global slope : di %4.2f _b[l_mean_`yr']
	global se: di  %4.2f _se[l_mean_`yr']

	twoway (scatter mean_growth_`yr'_`yrp' l_mean_`yr' if keep==1) (lfit mean_growth_`yr'_`yrp' l_mean_`yr' if keep==1), legend(off) title("`yr'-`yrp'") subtitle("Slope: ${slope} ; SE: ${se}") ytitle("Annual Income Growth Rate (in%)") xtitle("Log of mean labor earnings, `yr'") ylabel(-4(2)6) ymtick(-4(.5)6.5) xlabel(9.4(0.2)10.6) graphregion(color(white))
	graph save Graph "$maindir${sep}figs${sep}figure15B_`yr'.gph", replace
	graph export "$maindir${sep}figs${sep}figure15B_`yr'.png", as(png) replace
	
	drop keep
}
*

graph combine "$maindir${sep}figs${sep}figure15B_1995" "$maindir${sep}figs${sep}figure15B_2000" "$maindir${sep}figs${sep}figure15B_2005" "$maindir${sep}figs${sep}figure15B_2010", col(2) title("") graphregion(color(white)) note("")
graph save Graph "$maindir${sep}figs${sep}figure15B.gph", replace
graph export "$maindir${sep}figs${sep}figure15B.png", as(png) replace

foreach var in png gph {
	erase "$maindir${sep}figs${sep}figure15B_1995.`var'" 
	erase "$maindir${sep}figs${sep}figure15B_2000.`var'" 
	erase "$maindir${sep}figs${sep}figure15B_2005.`var'" 
	erase "$maindir${sep}figs${sep}figure15B_2010.`var'"
}
*

**Figure I1 B
*Using size instead of initial wage

_pctile mean_growth_1995_2015, p(1, 99)
gen keep = 1 if (mean_growth_1995_2015>r(r1) & mean_growth_1995_2015<r(r2))

qui: reg mean_growth_1995_2015 rank if keep == 1, r
global slope : di %4.3f 100*_b[rank]
global se: di  %4.3f 100*_se[rank]

twoway (scatter mean_growth_1995_2015 rank if keep==1) (lfit mean_growth_1995_2015 rank if keep==1), legend(off) title("") subtitle("Slope: ${slope} x 10{superscript:-2} ; SE: ${se} x 10{superscript:-2}") ytitle("Annual Income Growth Rate (in%)") xtitle("Rank based on population in 2015") ylabel(-2(1)3) ymtick(-2(0.5)3) xlabel() graphregion(color(white))
graph save Graph "$maindir${sep}figs${sep}figureI1_B.gph", replace
graph export "$maindir${sep}figs${sep}figureI1_B.png", as(png) replace

drop keep

}
*

}
*

**************************************
***Urban Unit of Paris vs. the Rest***
**************************************

***Figure 16

{
clear all
set more off
use "$maindir${sep}dta${sep}panel_1993_2015_uu2010"

keep if year>=1993

**Figure 16 A
*Log median wage between territories
twoway connected (p50_paris_C p50_paris_B p50_paris_I p50_paris_R) year, title("") subtitle("") ytitle("") ylabel(.1(.05).25) xtitle("") xlabel(1993(2)2015) graphregion(color(white)) legend(order(1 "Paris-Central municipalities" 2 "Paris-Suburbs" 3 "Paris-Remote areas" 4 "Paris-Rural areas") c(2)) lcolor(red blue green maroon) lpattern(solid longdash dash solid) msymbol(S T D X) lwidth(medthick) mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(red blue green maroon)
graph export "$maindir${sep}figs${sep}figure16A.png", replace
graph save Graph "$maindir${sep}figs${sep}figure16A.gph", replace 

**Figure 16 B
twoway connected (n_p50_paris_C n_p50_paris_B n_p50_paris_I n_p50_paris_R) year, title("") subtitle("") ytitle("Statistics Relative to 1993") ylabel(.03(.03)-0.09) ymtick(.03(.03)-0.09) xtitle("") xlabel(1993(2)2015) graphregion(color(white)) legend(order(1 "Paris-Central municipalities" 2 "Paris-Suburbs" 3 "Paris-Remote areas" 4 "Paris-Rural areas") c(2)) lcolor(red blue green maroon) lpattern(solid longdash dash solid) msymbol(S T D X) lwidth(medthick) mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(red blue green maroon)
graph export "$maindir${sep}figs${sep}figure16B.png", replace
graph save Graph "$maindir${sep}figs${sep}figure16B.gph", replace 

**Figure 16 C
*Log mean wage between territories
twoway connected (l_mean_paris_C l_mean_paris_B l_mean_paris_I l_mean_paris_R) year, title("") subtitle("") ytitle("") ylabel(.2(.05).4) xtitle("") xlabel(1993(2)2015) graphregion(color(white)) legend(order(1 "Paris-Central municipalities" 2 "Paris-Suburbs" 3 "Paris-Remote areas" 4 "Paris-Rural areas") c(2)) lcolor(red blue green maroon) lpattern(solid longdash dash solid) msymbol(S T D X) lwidth(medthick) mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(red blue green maroon)
graph export "$maindir${sep}figs${sep}figure16C.png", replace
graph save Graph "$maindir${sep}figs${sep}figure16C.gph", replace 

**Figure 16 D
twoway connected (n_l_mean_paris_C n_l_mean_paris_B n_l_mean_paris_I n_l_mean_paris_R) year, title("") subtitle("") ytitle("Statistics Relative to 1993") ylabel(-0.01(.01).07) xtitle("") xlabel(1993(2)2015) graphregion(color(white)) legend(order(1 "Paris-Central municipalities" 2 "Paris-Suburbs" 3 "Paris-Remote areas" 4 "Paris-Rural areas") c(2)) lcolor(red blue green maroon) lpattern(solid longdash dash solid) msymbol(S T D X) lwidth(medthick) mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(red blue green maroon)
graph export "$maindir${sep}figs${sep}figure16D.png", replace
graph save Graph "$maindir${sep}figs${sep}figure16D.gph", replace 

}
*

***********************************
***Share of Minimum Wage Workers***
***********************************

***Figures 17 & I2

{
clear all
set more off
use "$maindir${sep}dta${sep}panel_min_wage_uu2010"

**Figure 17
twoway connected (minimum_wage_P minimum_wage_C minimum_wage_B minimum_wage_I minimum_wage_R) year, title("") subtitle("") ytitle("") xtitle("") ylabel(0(5)25) xlabel(1993(2)2016) graphregion(color(white)) legend(order(1 "Paris" 2 "Central" 3 "Suburbs" 4 "Remote" 5 "Rural") c(3)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph export "$maindir${sep}figs${sep}figure17.png", replace
graph save Graph "$maindir${sep}figs${sep}figure17.gph", replace 


***By Gender
*Figure I.2

*Men
twoway connected (minimum_wage_m_P minimum_wage_m_C minimum_wage_m_B minimum_wage_m_I minimum_wage_m_R) year, title("") subtitle("") ytitle("") xtitle("") ylabel(0(5)30) xlabel(1993(2)2016) graphregion(color(white)) legend(order(1 "Paris" 2 "Central" 3 "Suburbs" 4 "Remote" 5 "Rural") c(3)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph export "$maindir${sep}figs${sep}figureI2A.png", replace
graph save Graph "$maindir${sep}figs${sep}figureI2A.gph", replace 

*Women
twoway connected (minimum_wage_f_P minimum_wage_f_C minimum_wage_f_B minimum_wage_f_I minimum_wage_f_R) year, title("") subtitle("") ytitle("") xtitle("") ylabel(0(5)30) xlabel(1993(2)2016) graphregion(color(white)) legend(order(1 "Paris" 2 "Central" 3 "Suburbs" 4 "Remote" 5 "Rural") c(3)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph export "$maindir${sep}figs${sep}figureI2B.png", replace
graph save Graph "$maindir${sep}figs${sep}figureI2B.gph", replace 

}
*

****************************
***Mobility between firms***
****************************

***Figure 18

{
clear all
set more off

use "$maindir${sep}dta${sep}firm_switchers_1993_2016"

drop if year==2016


***Establishment to establishment mobility

twoway connected (plant_switcher_P plant_switcher_C plant_switcher_B plant_switcher_I plant_switcher_R) year, title("") xtitle("") ylabel(10(5)30) xlabel(1993(2)2015) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(3)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir${sep}figs${sep}figure18.gph", replace
graph export "$maindir${sep}figs${sep}figure18.png", as(png) replace

/*

***Establishment to establishment mobility

*December to december mobility
twoway connected (plant_switcher_dec_P plant_switcher_dec_C plant_switcher_dec_B plant_switcher_dec_I plant_switcher_dec_R) year, title("") xtitle("") xlabel(1993(2)2015) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(3)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir${sep}figs${sep}plant_switchers_dec_territories.gph", replace
graph export "$maindir${sep}figs${sep}plant_switchers_dec_territories.png", as(png) replace

*Full time workers only
twoway connected (plant_switcher_ft_P plant_switcher_ft_C plant_switcher_ft_B plant_switcher_ft_I plant_switcher_ft_R) year, title("") xtitle("") ylabel(6(2)18) xlabel(1993(2)2015) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(3)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir${sep}figs${sep}plant_switchers_ft_territories.gph", replace
graph export "$maindir${sep}figs${sep}plant_switchers_ft_territories.png", as(png) replace

*Mobility from december to december for full time workers
twoway connected (plant_switcher_dec_ft_P plant_switcher_dec_ft_C plant_switcher_dec_ft_B plant_switcher_dec_ft_I plant_switcher_dec_ft_R) year, title("") xtitle("") ylabel(5(5)25) xlabel(1993(2)2015) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(3)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir${sep}figs${sep}plant_switchers_dec_ft_territories.gph", replace
graph export "$maindir${sep}figs${sep}plant_switchers_dec_ft_territories.png", as(png) replace


***Firm to firm mobility

twoway connected firm_switcher_P firm_switcher_C firm_switcher_B firm_switcher_I firm_switcher_R year, title("") xtitle("") xlabel(1993(2)2015) ylabel(5(5)25) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(3)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir${sep}figs${sep}firm_switchers_territories.gph", replace
graph export "$maindir${sep}figs${sep}firm_switchers_territories.png", as(png) replace

*December to december mobility
twoway connected firm_switcher_dec_P firm_switcher_dec_C firm_switcher_dec_B firm_switcher_dec_I firm_switcher_dec_R year, title("") xtitle("") xlabel(1993(2)2015) ylabel(05(5)25) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(3)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "firm_switchers_dec_typo_territories.gph", replace
graph export "firm_switchers_dec_typo_territories.png", as(png) replace

*Full time workers only
twoway connected firm_switcher_ft_P firm_switcher_ft_C firm_switcher_ft_B firm_switcher_ft_I firm_switcher_ft_R year, title("") xtitle("") xlabel(1993(2)2015) ylabel(3(1)10) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(3)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir${sep}figs${sep}firm_switchers_ft_typo_territories.gph", replace
graph export "$maindir${sep}figs${sep}firm_switchers_ft_typo_territories.png", as(png) replace

*Mobility from december to december for full time workers
twoway connected firm_switcher_dec_ft_P firm_switcher_dec_ft_C firm_switcher_dec_ft_B firm_switcher_dec_ft_I firm_switcher_dec_ft_R year, title("") xtitle("") xlabel(1993(2)2015) ylabel(5(5)15) ymtick(5(1)15) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(3)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir${sep}figs${sep}firm_switchers_dec_ft_territories.gph", replace
graph export "$maindir${sep}figs${sep}firm_switchers_dec_ft_territories.png", as(png) replace
*/
}
*

***********************************
***Paris center vs. Surroundings***
***********************************

***Figure 22

{

clear all
set more off
use "$maindir${sep}dta${sep}panel_1993_2015_paris"

*Median wage

twoway connected (p50_paris_2 p50_paris_3) year, lcolor(red blue green maroon black) lpattern(solid longdash dash solid longdash) msymbol(S + p) lwidth(medthick) mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 black*0.25) mlcolor(red blue green maroon black) title("") subtitle("") ylabel(-.15(.05).15) ytitle("") xtitle("") xlabel(1993(2)2016) graphregion(color(white)) legend(order(1 "Paris - Urban Unit w.o. Paris" 2 "Paris - Urban Area w.o. Urban Unit of Paris") c(1))
graph export "$maindir${sep}figs${sep}figure22A.png", replace
graph save Graph "$maindir${sep}figs${sep}figure22A.gph", replace 

*Mean wage

twoway connected (l_mean_paris_2 l_mean_paris_3) year, lcolor(red blue green maroon black) lpattern(solid longdash dash solid longdash) msymbol(S + p) lwidth(medthick) mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 black*0.25) mlcolor(red blue green maroon black) title("") subtitle("") ytitle("") ylabel(-.1(.1).3) xtitle("") xlabel(1993(2)2016) graphregion(color(white)) legend(order(1 "Paris - Urban Unit w.o. Paris" 2 "Paris - Urban Area w.o. Urban Unit of Paris") c(1))
graph export "$maindir${sep}figs${sep}figure22B.png", replace
graph save Graph "$maindir${sep}figs${sep}figure22B.gph", replace 

}
*

***************
***Local CPI***
***************

***Figure H2

{

**Figure H2 A: national CPI

clear all
set more off
use "$maindir${sep}dta${sep}panel_1993_2015_size"

keep if year>=1998 & year<=2012

twoway connected (n_l_mean_paris_5 n_l_mean_paris_4 n_l_mean_paris_3 n_l_mean_paris_2 n_l_mean_paris_1) year, lcolor(blue red orange green maroon) lpattern(longdash solid dash_dot dash solid) msymbol(T S O D X) lwidth(medthick) mfcolor(blue*0.25 red*0.25 orange*0.25 green*0.25 maroon*0.25) mlcolor(blue red orange green maroon) title("") subtitle("") ytitle("Statistics relative to 1998") ylabel(0(.05).20) ymtick(0(.01).20) xtitle("") xlabel(1998(2)2012) graphregion(color(white)) legend(order(1 "Paris - Suburbs of Paris" 2 "Paris - more than 100k" 3 "Paris - btw 20k-100k" 4 "Paris - <20k inhabitants" 5 "Paris-Rural areas") c(2))
graph export "$maindir${sep}figs${sep}figureH2A_mean.png", replace
graph save Graph "$maindir${sep}figs${sep}figureH2A_mean.gph", replace 

twoway connected (n_p50_paris_5 n_p50_paris_4 n_p50_paris_3 n_p50_paris_2 n_p50_paris_1) year, lcolor(blue red orange green maroon) lpattern(longdash solid dash_dot dash solid) msymbol(T S O D X) lwidth(medthick) mfcolor(blue*0.25 red*0.25 orange*0.25 green*0.25 maroon*0.25) mlcolor(blue red orange green maroon) title("") subtitle("") ytitle("Statistics relative to 1998") ylabel(0(.05).15) ymtick(0(.01).15) xtitle("") xlabel(1998(2)2012) graphregion(color(white)) legend(order(1 "Paris - Suburbs of Paris" 2 "Paris - more than 100k" 3 "Paris - btw 20k-100k" 4 "Paris - <20k inhabitants" 5 "Paris-Rural areas") c(2))
graph export "$maindir${sep}figs${sep}figureH2A_median.png", replace
graph save Graph "$maindir${sep}figs${sep}figureH2A_median.gph", replace 


**Figure H2 B: local CPI

clear all
set more off
use "$maindir${sep}dta${sep}panel_1993_2015_size_local_cpi"

keep if year>=1998 & year<=2012

twoway connected (n_l_mean_paris_5 n_l_mean_paris_4 n_l_mean_paris_3 n_l_mean_paris_2 n_l_mean_paris_1) year, lcolor(blue red orange green maroon) lpattern(longdash solid dash_dot dash solid) msymbol(T S O D X) lwidth(medthick) mfcolor(blue*0.25 red*0.25 orange*0.25 green*0.25 maroon*0.25) mlcolor(blue red orange green maroon) title("") subtitle("") ytitle("Statistics relative to 1998") ylabel(0(.05).20) ymtick(0(.01).20) xtitle("") xlabel(1998(2)2012) graphregion(color(white)) legend(order(1 "Paris - Suburbs of Paris" 2 "Paris - More than 100k" 3 "Paris - 20k-100k inhabs" 4 "Paris - <20k inhabs." 5 "Paris-Rural areas") c(2))
graph export "$maindir${sep}figs${sep}figureH2B_mean.png", replace
graph save Graph "$maindir${sep}figs${sep}figureH2B_mean.gph", replace 

twoway connected (n_p50_paris_5 n_p50_paris_4 n_p50_paris_3 n_p50_paris_2 n_p50_paris_1) year, lcolor(blue red orange green maroon) lpattern(longdash solid dash_dot dash solid) msymbol(T S O D X) lwidth(medthick) mfcolor(blue*0.25 red*0.25 orange*0.25 green*0.25 maroon*0.25) mlcolor(blue red orange green maroon) title("") subtitle("") ytitle("Statistics relative to 1998") ylabel(0(.05).15) ymtick(0(.01).15) xtitle("") xlabel(1998(2)2012) graphregion(color(white)) legend(order(1 "Paris - Suburbs of Paris" 2 "Paris - More than 100k" 3 "Paris - 20k-100k inhabs." 4 "Paris - <20k inhabs." 5 "Paris-Rural areas") c(2))
graph export "$maindir${sep}figs${sep}figureH2B_median.png", replace
graph save Graph "$maindir${sep}figs${sep}figureH2B_median.gph", replace 

}
*

**********************************
***Mobility between territories***
**********************************

***Figures I3-5

{

clear all
set more off

use "$maindir${sep}dta${sep}mobility_territories.dta"

foreach var in mob_B mob_C mob_I mob_R mob_P mob_B_C mob_B_I mob_B_R mob_B_P mob_C_B mob_C_I mob_C_R mob_C_P mob_I_B mob_I_C mob_I_R mob_I_P mob_R_B mob_R_C mob_R_I mob_R_P mob_P_B mob_P_C mob_P_I mob_P_R mob_from_B mob_from_C mob_from_I mob_from_R mob_from_P {
	gen n_`var'=log(`var')
	qui sum n_`var' if year==1993
	replace n_`var' = n_`var' - r(mean)
}
*

**Figure I.3
*Rate of mobility (National)
tw connected (mobility_muni mobility_CZ) year, title("") xtitle("") ylabel() xlabel(1993(2)2015) legend(order(1 "Municipality" 2 "CZ")) graphregion(color(white))
graph save Graph "$maindir${sep}figs${sep}figureI3.gph", replace
graph export "$maindir${sep}figs${sep}figureI3.png", as(png) replace

**Figure I.4A
*Mobility from a given territory
twoway connected (mob_from_P mob_from_C mob_from_B mob_from_I mob_from_R) year,  title("") xtitle("") ylabel() xlabel(1993(2)2015) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(2)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir${sep}figs${sep}figureI4A.gph", replace
graph export "$maindir${sep}figs${sep}figureI4A.png", as(png) replace

**Figure I.4B
*Mobility to Paris
twoway connected (mob_C_P mob_B_P mob_I_P mob_R_P) year,  title("") xtitle("") ylabel() xlabel(1993(2)2015) legend(order(1 "Central Municipalities" 2 "Suburban areas" 3 "Remote areas" 4 "Rural areas") c(2)) graphregion(color(white)) lcolor(red blue green maroon) lpattern(solid longdash dash solid) msymbol(S T D X) lwidth(medthick) mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(red blue green maroon)
graph save Graph "$maindir${sep}figs${sep}figureI4B.gph", replace
graph export "$maindir${sep}figs${sep}figureI4B.png", as(png) replace

**Figure I.5
*Rank of movers in the Permanent earnings (national) distribution
tw connected (permrankt_mob_P permrankt_mob_C permrankt_mob_B permrankt_mob_I permrankt_mob_R) year, title("") subtitle("") xtitle("") ylabel() xlabel(1993(2)2015) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(2)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
graph save Graph "$maindir${sep}figs${sep}figureI5", replace
graph export "$maindir${sep}figs${sep}figureI5.png", as(png) replace

*Rank of movers in the Residualized earnings (national) distribution
*tw connected (resrankt_mob_P resrankt_mob_C resrankt_mob_B resrankt_mob_I resrankt_mob_R) year, title("") subtitle("") xtitle("") ylabel() xlabel(1993(2)2015) legend(order(1 "Paris" 2 "Central Municipalities" 3 "Suburban areas" 4 "Remote areas" 5 "Rural areas") c(2)) graphregion(color(white)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
*graph save Graph "$maindir${sep}figs${sep}figureI5_residual_earnings", replace
*graph export "$maindir${sep}figs${sep}figureI5_residual_earnings.png", as(png) replace



}
*

****************************************
***Wage growth for movers vs. stayers***
****************************************

***Figures I6 & I7

{

clear all
set more off
use "$maindir${sep}dta${sep}hist_5y"

***Five year growth

**Figure I.6
*Five-year log earnings growth for stayers

twoway (line den_researn5F_8 val_researn5F_8 if val_researn5F_8>=-2.5 & val_researn5F_8<=2.5) ///
	(line den_researn5F_9 val_researn5F_9 if val_researn5F_9>=-2.5 & val_researn5F_9<=2.5) ///
	(line den_researn5F_10 val_researn5F_10 if val_researn5F_10>=-2.5 & val_researn5F_10<=2.5),  ytitle("Density") xtitle("Five-Year Log Earnings Growth") xlabel(-2.5(0.5)2.5) ylabel(0(1)3) ///
	legend(order(1 "Stayers Paris" 2 "Stayers Prov" 3 "Stayers Rural") c(3)) graphregion(color(white)) 
graph save Graph "$maindir${sep}figs${sep}figureI6_5F.gph", replace
graph export "$maindir${sep}figs${sep}figureI6_5F.png", as(png) replace


**Figure I.7

twoway (line den_researn5F_1 val_researn5F_1 if val_researn5F_1>=-2.5 & val_researn5F_1<=2.5) ///
	(line den_researn5F_3 val_researn5F_3 if val_researn5F_3>=-2.5 & val_researn5F_3<=2.5) ///
	(line den_researn5F_5 val_researn5F_5 if val_researn5F_5>=-2.5 & val_researn5F_5<=2.5) ///
	(line den_researn5F_6 val_researn5F_6 if val_researn5F_6>=-2.5 & val_researn5F_6<=2.5),  ytitle("Density") xtitle("Five-Year Log Earnings Growth") xlabel(-2.5(0.5)2.5) ylabel(0(1)3) ///
	legend(order(1 "Prov->Paris" 2 "Rural->Paris" 3 "Paris->Prov" 4 "Paris->Rural") c(2)) graphregion(color(white)) 
graph save Graph "$maindir${sep}figs${sep}figureI7A_5F.gph", replace
graph export "$maindir${sep}figs${sep}figureI7A_5F.png", as(png) replace


twoway (line den_researn5F_2 val_researn5F_2 if val_researn5F_2>=-2.5 & val_researn5F_2<=2.5) ///
	(line den_researn5F_4 val_researn5F_4 if val_researn5F_4>=-2.5 & val_researn5F_4<=2.5) ///
	(line den_researn5F_7 val_researn5F_7 if val_researn5F_7>=-2.5 & val_researn5F_7<=2.5),  ytitle("Density") xtitle("Five-Year Log Earnings Growth") xlabel(-2.5(0.5)2.5) ylabel(0(.5)3) ///
	legend(order(1 "Prov->Rural" 2 "Rural->Prov" 3 "Prov->Prov") c(3)) graphregion(color(white)) 
graph save Graph "$maindir${sep}figs${sep}figureI7B_5F.gph", replace
graph export "$maindir${sep}figs${sep}figureI7B_5F.png", as(png) replace


/*

***One year growth

clear all
set more off
use "$maindir${sep}dta${sep}hist_1y"

**Figure I.6
*Five-year log earnings growth for stayers

twoway (line den_researn1F_8 val_researn1F_8 if val_researn1F_8>=-2.5 & val_researn1F_8<=2.5) ///
	(line den_researn1F_9 val_researn1F_9 if val_researn1F_9>=-2.5 & val_researn1F_9<=2.5) ///
	(line den_researn1F_10 val_researn1F_10 if val_researn1F_10>=-2.5 & val_researn1F_10<=2.5),  ytitle("Density") xtitle("One-Year Log Earnings Growth") xlabel(-2.5(0.5)2.5) ylabel(0(1)6) ///
	legend(order(1 "Stayers Paris" 2 "Stayers Prov" 3 "Stayers Rural") c(3)) graphregion(color(white)) 
graph save Graph "$maindir${sep}figs${sep}figureI6_1F.gph", replace
graph export "$maindir${sep}figs${sep}figureI6_1F.png", as(png) replace


**Figure I.7
*Five-year log earnings growth for movers

twoway (line den_researn1F_1 val_researn1F_1 if val_researn1F_1>=-2.5 & val_researn1F_1<=2.5) ///
	(line den_researn1F_3 val_researn1F_3 if val_researn1F_3>=-2.5 & val_researn1F_3<=2.5) ///
	(line den_researn1F_5 val_researn1F_5 if val_researn1F_5>=-2.5 & val_researn1F_5<=2.5) ///
	(line den_researn1F_6 val_researn1F_6 if val_researn1F_6>=-2.5 & val_researn1F_6<=2.5),  ytitle("Density") xtitle("") xlabel(-2.5(0.5)2.5) ylabel(0(1)6) ///
	legend(order(1 "Prov->Paris" 2 "Rural->Paris" 3 "Paris->Prov" 4 "Paris->Rural") c(2)) graphregion(color(white)) 
graph save Graph "$maindir${sep}figs${sep}figureI7A_1F.gph", replace
graph export "$maindir${sep}figs${sep}figureI7A_1F.png", as(png) replace


twoway (line den_researn1F_2 val_researn1F_2 if val_researn1F_2>=-2.5 & val_researn1F_2<=2.5) ///
	(line den_researn1F_4 val_researn1F_4 if val_researn1F_4>=-2.5 & val_researn1F_4<=2.5) ///
	(line den_researn1F_7 val_researn1F_7 if val_researn1F_7>=-2.5 & val_researn1F_7<=2.5),  ytitle("Density") xtitle("") xlabel(-2.5(0.5)2.5) ylabel(0(1)6) ///
	legend(order(1 "Prov->Rural" 2 "Rural->Prov" 3 "Prov->Prov") c(3)) graphregion(color(white)) 
graph save Graph "$maindir${sep}figs${sep}figureI7B_1F.gph", replace
graph export "$maindir${sep}figs${sep}figureI7B_1F.png", as(png) replace

*/

}
*


***********************
***Public Employment***
***********************

***Figures I.8 to I.10

{

***Shares

foreach v in sec { //sec
*

clear all
set more off

use "$maindir${sep}dta${sep}`v'_panel_share_public_2002_2016"


if "`v'"=="dom" {
global ylabel_type = "ylabel(-1(.5)1) ymtick(-1(.25)1)"
}
if "`v'"=="sec" {
global ylabel_type = "ylabel(-.5(.25)1) ymtick(-.5(.125)1)"
}
*

foreach var in ftfy { //dp ftfy
*Dp: measure of employment based on the number of days of work
*ftfy: employment of workers working full time the whole year

	***Figure I.8 A
	**Total public employment (national level)
	*Normalized number of jobs
	tw (line n_`v'_fp_total_`var' year), graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Employment relative to 2002") ylabel(-.15(.05).05) ymtick()
	graph save Graph "$maindir${sep}figs${sep}figureI8A_`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureI8A_`var'.eps", as(eps) preview(off) replace
	graph export "$maindir${sep}figs${sep}figureI8A_`var'.png", as(png) replace


	***Figure I.8 B
	**Total public employment (local level)
	*Normalized number of jobs
	tw connected (n_`v'_fp_total_`var'_P n_`v'_fp_total_`var'_C n_`v'_fp_total_`var'_B n_`v'_fp_total_`var'_I n_`v'_fp_total_`var'_R year) , graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Employment share relative to 2002") ylabel(-.2(.1).2) ymtick() legend(order(1 "Paris" 2 "Central" 3 "Suburbs" 4 "Remote" 5 "Rural") c(3)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
	graph save Graph "$maindir${sep}figs${sep}figureI8B_`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureI8B_`var'.eps", as(eps) preview(off) replace
	graph export "$maindir${sep}figs${sep}figureI8B_`var'.png", as(png) replace

	***Figure I.8 C
	**Total public employment (national level)
	*Normalized shares
	if "`var'"=="dp" tw (line n_`v'_s_fp_total_`var' year), graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Employment share relative to 2002") ylabel(-.05(.05).1) ymtick(-.05(0.01).10)
	if "`var'"=="ftfy" tw (line n_`v'_s_fp_total_`var' year), graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Employment share relative to 2002") ylabel(-.05(.05).05) ymtick(-.05(0.01).05)
	graph save Graph "$maindir${sep}figs${sep}figureI8C_`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureI8C_`var'.eps", as(eps) preview(off) replace
	graph export "$maindir${sep}figs${sep}figureI8C_`var'.png", as(png) replace

	*Shares
	/*
	tw (line `v'_s_fp_total_`var' year), graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Employment share (in %)") ylabel(20(5)30) ymtick(20(1)30) 
	graph save Graph "$maindir${sep}figs${sep}figureI8C_`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureI8C_`var'.eps", as(eps) preview(off) replace
	graph export "$maindir${sep}figs${sep}figureI8C_`var'.png", as(png) replace
	*/

	
	***Figure I.8 D
	**Total public employment (local level)
	*Normalized shares
	tw connected (n_`v'_s_fp_total_`var'_P n_`v'_s_fp_total_`var'_C n_`v'_s_fp_total_`var'_B n_`v'_s_fp_total_`var'_I n_`v'_s_fp_total_`var'_R year) , graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Employment share relative to 2002") ylabel(-.15(.05).15) ymtick() legend(order(1 "Paris" 2 "Central" 3 "Suburbs" 4 "Remote" 5 "Rural") c(3)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
	graph save Graph "$maindir${sep}figs${sep}figureI8D_`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureI8D_`var'.eps", as(eps) preview(off) replace
	graph export "$maindir${sep}figs${sep}figureI8D_`var'.png", as(png) replace
	
	*Shares
	/*
	tw connected (`v'_s_fp_total_`var'_P `v'_s_fp_total_`var'_C `v'_s_fp_total_`var'_B `v'_s_fp_total_`var'_I `v'_s_fp_total_`var'_R year), graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Employment share (in %)") ylabel(0(10)40) ymtick(0(5)40) legend(order(1 "Paris" 2 "Central" 3 "Suburbs" 4 "Remote" 5 "Rural") c(3)) lcolor(black red blue green maroon) lpattern(dash_dot solid longdash dash solid) msymbol(O S T D X) lwidth(medthick) mfcolor(black*0.25 red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(black red blue green maroon)
	graph save Graph "$maindir${sep}figs${sep}figureI8D_`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureI8D_`var'.eps", as(eps) preview(off) replace
	graph export "$maindir${sep}figs${sep}figureI8D_`var'.png", as(png) replace
	*/
	
	***Figure I.9 A
	**Public employment by type (national level)
	*In thousands
	
	foreach temp in `v'_fp_etat_`var' `v'_fp_local_`var' `v'_fp_hopitaux_`var' {
		cap drop temp_`temp'
		cap gen temp_`temp' = `temp'/1000
	}
	
	tw connected (temp_`v'_fp_etat_`var' temp_`v'_fp_local_`var' temp_`v'_fp_hopitaux_`var' year), graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Observations (in thousands)") ylabel(40(20)120) legend(order(1 "State civil servants" 2 "Local civil servants" 3 "Hospitals") c(3)) lcolor(red blue green) mfcolor(red*0.25 blue*0.25 green*0.25) mlcolor(red blue green) lpattern(solid longdash dash) msymbol(s + p) lwidth(medthick)
	graph save Graph "$maindir${sep}figs${sep}figureI9A_`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureI9A_`var'.eps", as(eps) preview(off) replace
	graph export "$maindir${sep}figs${sep}figureI9A_`var'.png", as(png) replace
	
	***Figure I.9 B
	**Public employment by type (national level)
	*In thousands (normalized)
	tw connected (n_`v'_fp_etat_`var' n_`v'_fp_local_`var' n_`v'_fp_hopitaux_`var' year), graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Employment relative to 2002") ylabel(-.5(.2).5) ymtick(-.5(.1).5) legend(order(1 "State civil servants" 2 "Local civil servants" 3 "Hospitals") c(3)) lcolor(red blue green) mfcolor(red*0.25 blue*0.25 green*0.25) mlcolor(red blue green) lpattern(solid longdash dash) msymbol(s + p) lwidth(medthick)
	graph save Graph "$maindir${sep}figs${sep}figureI9B_`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureI9B_`var'.eps", as(eps) preview(off) replace
	graph export "$maindir${sep}figs${sep}figureI9B_`var'.png", as(png) replace
		
	***Figure I.9 C
	**Public employment by type (national level)
	*Shares
	tw connected (`v'_s_fp_etat_`var' `v'_s_fp_local_`var' `v'_s_fp_hopitaux_`var' year), graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Employment share (in %)") ylabel(0(5)15) ymtick(0(1)15) legend(order(1 "State civil servants" 2 "Local civil servants" 3 "Hospitals") c(3)) lcolor(red blue green) mfcolor(red*0.25 blue*0.25 green*0.25) mlcolor(red blue green) lpattern(solid longdash dash) msymbol(s + p) lwidth(medthick)
	graph save Graph "$maindir${sep}figs${sep}figureI9C_`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureI9C_`var'.eps", as(eps) preview(off) replace
	graph export "$maindir${sep}figs${sep}figureI9C_`var'.png", as(png) replace
	
	
	***Figure I.9 D
	*Normalized shares
	tw connected (n_`v'_s_fp_etat_`var' n_`v'_s_fp_local_`var' n_`v'_s_fp_hopitaux_`var' year), graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Employment share relative to 2002") ylabel(-.40(.2).4) ymtick(-.40(.1).4) legend(order(1 "State civil servants" 2 "Local civil servants" 3 "Hospitals") c(3)) lcolor(red blue green) mfcolor(red*0.25 blue*0.25 green*0.25) mlcolor(red blue green) lpattern(solid longdash dash) msymbol(s + p) lwidth(medthick)
	graph save Graph "$maindir${sep}figs${sep}figureI9D_`var'.gph", replace
	graph export "$maindir${sep}figs${sep}figureI9D_`var'.eps", as(eps) preview(off) replace
	graph export "$maindir${sep}figs${sep}figureI9D_`var'.png", as(png) replace

	***Figure 10
	**By type of public job

	foreach area in P C B I R {
	
		if "`area'"=="P" {
			local title = "A"
		}
		if "`area'"=="C" {
			local title = "B"
		}
		if "`area'"=="B" {
			local title = "C"
		}
		if "`area'"=="I" {
			local title = "D"
		}
		if "`area'"=="R" {
			local title = "E"
		}
		
		***
		
		tw connected (n_`v'_s_fp_etat_`var'_`area' n_`v'_s_fp_local_`var'_`area' n_`v'_s_fp_hopitaux_`var'_`area' year) , graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2002(1)2016) ytitle("Relative to 2002") $ylabel_type legend(order(1 "State" 2 "Local" 3 "Hospitals") c(3)) lcolor(red blue green) mfcolor(red*0.25 blue*0.25 green*0.25) mlcolor(red blue green) lpattern(solid longdash dash) msymbol(s + p) lwidth(medthick)
		graph save Graph "$maindir${sep}figs${sep}figureI10`title'_`var'.gph", replace
		graph export "$maindir${sep}figs${sep}figureI10`title'_`var'.eps", as(eps) preview(off) replace
		graph export "$maindir${sep}figs${sep}figureI10`title'_`var'.png", as(png) replace

		*Shares
		/*
		tw connected (`v'_s_fp_etat_`var'_`area' `v'_s_fp_local_`var'_`area' `v'_s_fp_hopitaux_`var'_`area' `v'_s_fp_others_`var'_`area' year) , graphregion(color(white)) title("") xtitle("") xlabel(2002(2)2016) xmtick(2001(1)2016) ytitle("Share (in %)") ylabel(0(5)20) ymtick(0(1)20) legend(order(1 "State" 2 "Local" 3 "Hospitals" 4 "Others")) lcolor(red blue green maroon) mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25) mlcolor(red blue green maroon) lpattern(solid longdash dash solid) msymbol(s + p o) lwidth(medthick)
		graph save Graph "$maindir${sep}figs${sep}figureI10`title'_`var'.gph", replace
		graph export "$maindir${sep}figs${sep}figureI10`title'_`var'.eps", as(eps) preview(off) replace
		graph export "$maindir${sep}figs${sep}figureI10`title'_`var'.png", as(png) replace	
		*/
	}
	*
}
*
}
*

}
*
