

		***********************************
		***PANEL tous salariés 1976-2018***
		***********************************
	
	
***********
***Paths***
***********

global out = "$maindir_replication${sep}Part_A${sep}dta"


**********************
***Merge Panel 2018***
**********************

{
clear all
set more off

append using "$sources${sep}panel18_76_93"
append using "$sources${sep}panel18_94_01"
append using "$sources${sep}panel18_02_07"
append using "$sources${sep}panel18_08_12"
append using "$sources${sep}panel18_13_18"

compress

erase "$sources${sep}panel18_76_93dta"
erase "$sources${sep}panel18_94_01dta"
erase "$sources${sep}panel18_02_07dta"
erase "$sources${sep}panel18_08_12dta"
erase "$sources${sep}panel18_13_18dta"

save "$sources${sep}panel_ts_2018", replace

}
*

	*********************
	***PANEL 1976-2018***
	*********************

{

clear all
set more off

use "$sources${sep}panel_ts_2018.dta"

***Rename variables 
rename nninouv idnr
rename annai b_year
rename an year
rename sir siren

***Period (1991-2016)
drop if year < 1991
drop if year > 2016 

***Observations with a problematic identifier
*1994, 2003 and 2004 have a higher share of missing identifiers Including these observations entails abnormal drops in bottom percentiles 
drop if substr(idnr,1,1)=="F"

drop if idnr=="" | idnr=="" //missing workers' identifier

drop if sb <=0 | sb==. //"Particuliers employeurs" have 0 sb


***Year of death (ie the individual leaves the sample)
bys idnr : egen yod = max(year)
replace yod = yod+1

***Year of birth
*Some missing values but always the same dob for a given individual
sort idnr sb
by idnr : replace b_year = b_year[_N] if  b_year[_N]!=.
by idnr : replace b_year = b_year[_N-1] if  b_year[_N]==. & b_year[_N-1]!=.
by idnr : replace b_year = b_year[_N-2] if  b_year[_N]==. & b_year[_N-1]==. & b_year[_N-2]!=.

drop if b_year==.
gen ag = year-b_year + 1

***Gender
*People are coded as male if we observe mainly sx==1
gen male = .
destring sx, replace
by idnr : egen total_sx = total(sx)
gen non_empty = 0
replace non_empty = 1 if sx==0 | sx==1
by idnr : egen total_nonempty = total(non_empty)
by idnr : replace male = 1 if total_nonempty!=0 & (total_sx >=0.5 * total_nonempty)
by idnr : replace male = 0 if total_nonempty!=0 & (total_sx <0.5 * total_nonempty)
drop if male==.
drop total_sx non_empty total_nonempty sx


*************
***Filters***
*************

***France métropolitaine
**Keep jobs in France Métropolitaine (dept in [01,95] + 2A-2B Corse)

forvalue i = 1/9 {
replace dept="0`i'" if dept=="`i'"
}

gen dept2=substr(dept,1,2)
replace dept = "" if dept=="ZZ" 
replace dept = "" if dept2=="00" | dept2=="" | dept2==""
replace dept = "99" if inlist(dept, "9A", "9B", "9C", "9D", "XX")
replace dept = "99" if inlist(dept2,"97","98")
drop if dept=="99" | dept==""
drop dept2

***Age
*Ag is defined as: ag = year-b_year + 1

keep if ag >=24
keep if ag <=55

*Drop people that should not be observe 1991 due to the sampling procedure

drop if inlist(ag,25,29,33,35,37,43,45,55) & year==1991

***Education

merge m:1 idnr using "$processing${sep}panel_ts_edp_2018_clean"
drop if _merge==2
drop _merge


***Occupation
*(cs1/cs2: since 1984)

drop if cs1=="0" //cs1=="0" corresponds to ce=="A" (workers collecting unemployment insurance)
drop if cs1=="1" //AGRICULTURE
drop if cs2=="44" // CLERGY
drop if substr(cs2,1,1)=="7" //TRAINEES AND APPRENTICES
drop if cs1=="7" //TRAINEES AND APPRENTICES


***Workers collecting unemployment
*(since 2008)
drop if ce=="A"

keep if inlist(filtre,"0","1")

***Sirens fictifs Pseudo siren Particuliers employeurs
gen first=substr(siren,1,1)
drop if first=="S" // Particuliers employeurs
replace siren = "" if first=="P" // Pseudo siren
replace siren = "" if first=="F"
drop first


***Keep the same sample as in the comprehensive DADS
*(domempl: since 1986)

drop if domempl =="7" // Particuliers employeurs
drop if domempl =="1" // Fonction publique d'Etat (FPE)

gen private = 1
replace private = 0 if domempl =="1" | domempl =="2" | domempl =="3" | domempl =="4"

*domempl =="1" // Fonction publique d'Etat
*domempl =="2" // Fonction publique territoriale
*domempl =="3" // Fonction publique hospitalière
*domempl =="4" // Autres organismes publics administratifs

***Wages and hours

replace nbheur = . if nbheur <0

replace nbheur = 2496 if nbheur > 2496 & nbheur!=. //48*52=2496 (Loi Seguin 1987) 

gen empty_h = (nbheur==0 | nbheur==.)

***Total gross/net labour income and nber of hours (Public + private)

bys idnr year: egen total_g_wage = total(sb)
bys idnr year: egen total_n_wage = total(sn)
bys idnr year: egen total_netnet_wage = total(netnet)
bys idnr year: egen total_hours = total(nbheur)

bys idnr year: egen empty_hours = total(empty_h)
replace empty_hours = 1 if empty_hours>0
drop empty_h

*Inconsistent earnings

replace total_g_wage = . if total_g_wage > 15 * total_n_wage & total_n_wage>0 & total_n_wage!=.

gen wage_inc = total_g_wage

***Irrelevant variables

drop domempl sect
drop pan25 pannouv
drop age
drop filtre

******************
***Main databse***
******************

preserve

***Keep only one obs by individual x year

sort idnr year sb
by idnr year: keep if _n==_N
duplicates drop idnr year, force

***Save data

keep year b_year idnr yod ag male wage_inc educ 
compress

sort idnr year
egen personid = group(idnr)

save "$out${sep}panel_dads_edp_1991_2016.dta", replace

restore

**************************
***Additional variables***
**************************

*Will be merged with the master database
*Provides: the place of residence, number of hours, characteristics of the main job
*We exclude Corsica from geographical analysis since data are not available every year


***Main Firm/Plant in December
*Used to study transitions between firms

{
gen siret = siren+nic4

gen dec = (finremu>=330 | dp==360) if finremu!=.
replace dec = 0 if finremu==. & dp!=360

sort idnr year dec sb

by idnr year: gen siren_dec = siren[_N] if dec==1
by idnr year: gen siret_dec = siret[_N] if dec==1
by idnr year: replace siren_dec = siren[_N-1] if dec[_N-1]==1 & siren[_N]==""
by idnr year: replace siret_dec = siret[_N-1] if dec[_N-1]==1 & siret[_N]==""
by idnr year: replace siren_dec = siren[_N-2] if dec[_N-2]==1 & siren[_N]=="" & siren[_N-1]==""
by idnr year: replace siret_dec = siret[_N-2] if dec[_N-2]==1 & siret[_N]=="" & siret[_N-1]==""

sort idnr year siren_dec
by idnr year: replace siren_dec = siren_dec[_N] if siren_dec[_N]!=""
by idnr year: replace siren_dec = siren_dec[_N-1] if siren_dec[_N]=="" & siren_dec[_N-1]!=""

sort idnr year siret_dec
by idnr year: replace siret_dec = siret_dec[_N] if siret_dec[_N]!=""
by idnr year: replace siret_dec = siret_dec[_N-1] if siret_dec[_N]=="" & siret_dec[_N-1]!=""

}
*

***Main Job

{
*Main job

sort idnr year sb
by idnr year: gen main_job = (_n==_N)

*Main job full time

gen ft = 0
replace ft = 1 if ce=="C" & main_job==1

*Main job full year full time

gen ft_fy = 0
replace ft_fy = 1 if ce=="C" & main_job==1 & dp >=350

}
*

***************
***Geography***
***************

{
**Place of residence & place of work

gen lgt1=length(comr)
replace comr="" if lgt1<3

gen lgt2=length(comt)
replace comt="" if lgt2<3

drop lgt1 lgt2

gen end_r = substr(comr,3,1)
gen keep_r = 1 if inlist(end_r,"0","1","2","3","4","5","6","7","8") | end_r=="9"
replace comr="" if keep_r!=1
*
gen end_t = substr(comt,3,1)
gen keep_t = 1 if inlist(end_t,"0","1","2","3","4","5","6","7","8") | end_t=="9"
replace comt="" if keep_t!=1

*
drop end_r keep_r end_t keep_t


*"Département" of residence
replace depr = "" if inlist(depr, "00", "0", "ZZ", "96")
replace depr = "" if inlist(depr, "AR", "BE", "BH", "CA", "CB", "CT", "IA", "ME", "MN")
replace depr = "" if inlist(depr, "NW", "SE", "SG", "SU")
replace depr = "" if inlist(depr, "97", "970", "971", "972", "973", "974", "975", "976", "977")
replace depr = "" if inlist(depr, "978", "98", "99", "9A", "9B", "9C", "9D","B6")
replace depr = "" if inlist(depr, "986", "987", "988")

*commune_r: used for inequality between areas We keep the information of the main job

gen commune_r = ""
gen commune_t = ""
replace commune_r = depr + comr if depr!="" & comr!=""
replace commune_t = dept + comt if dept!="" & comt!=""

sort idnr year sb

by idnr year : replace commune_r = commune_r[_N] if commune_r[_N]!=""
by idnr year : replace commune_r = commune_r[_N-1] if commune_r[_N]=="" & commune_r[_N-1]!=""
by idnr year : replace commune_r = commune_r[_N-2] if commune_r[_N]=="" & commune_r[_N-1]=="" & commune_r[_N-2]!=""
by idnr year : replace commune_r = commune_r[_N-3] if commune_r[_N]=="" & commune_r[_N-1]=="" & commune_r[_N-2]=="" & commune_r[_N-3]!=""


gen code_commune = commune_r

*Paris
replace code_commune = "75056" if inlist(code_commune, "75101","75102","75103","75104","75105","75106","75107","75108","75109")
replace code_commune = "75056" if inlist(code_commune, "75110","75111","75112","75113","75114","75115","75116","75117","75118")
replace code_commune = "75056" if inlist(code_commune, "75119","75120")
*Lyon
replace code_commune = "69123" if inlist(code_commune, "69381","69382","69383","69384","69385","69386","69387","69388","69389")
*Marseille
replace code_commune = "13055" if inlist(code_commune, "13201","13202","13203","13204","13205","13206","13207","13208","13209")
replace code_commune = "13055" if inlist(code_commune, "13210","13211","13212","13213","13214","13215","13216")

*Changes in the municipality code over time
replace code_commune="02580" if code_commune=="02247"
replace code_commune="02559" if code_commune=="02611"
replace code_commune="02738" if code_commune=="02630"
replace code_commune="04155" if code_commune=="04029"
replace code_commune="07031" if code_commune=="07046"
replace code_commune="07147" if code_commune=="07125"
replace code_commune="07284" if code_commune=="07246"
replace code_commune="07147" if code_commune=="07320"
replace code_commune="08169" if code_commune=="08221"
replace code_commune="14697" if code_commune=="14624"
replace code_commune="16339" if code_commune=="16022"
replace code_commune="16297" if code_commune=="16159"
replace code_commune="19275" if code_commune=="19267"
replace code_commune="21084" if code_commune=="21551"
replace code_commune="25485" if code_commune=="25577"
replace code_commune="26262" if code_commune=="26151"
replace code_commune="26091" if code_commune=="26158"
replace code_commune="26020" if code_commune=="26265"
replace code_commune="27297" if code_commune=="27328"
replace code_commune="33342" if code_commune=="33286"
replace code_commune="35064" if code_commune=="35036"
replace code_commune="35206" if code_commune=="35073"
replace code_commune="38139" if code_commune=="38227"
replace code_commune="39385" if code_commune=="39005"
replace code_commune="39367" if code_commune=="39524"
replace code_commune="49206" if code_commune=="49210"
replace code_commune="50216" if code_commune=="50303"
replace code_commune="50129" if code_commune=="50383"
replace code_commune="51158" if code_commune=="51021"
replace code_commune="51158" if code_commune=="51024"
replace code_commune="51158" if code_commune=="51383"
replace code_commune="53062" if code_commune=="53024"
replace code_commune="54602" if code_commune=="55227"
replace code_commune="55060" if code_commune=="55337"
replace code_commune="55060" if code_commune=="55354"
replace code_commune="57132" if code_commune=="57157"
replace code_commune="57133" if code_commune=="57170"
replace code_commune="57150" if code_commune=="57420"   
replace code_commune="59350" if code_commune=="59298"
replace code_commune="59350" if code_commune=="59355"
replace code_commune="59183" if code_commune=="59380"
replace code_commune="61483" if code_commune=="61022"
replace code_commune="61136" if code_commune=="61254"
replace code_commune="62473" if code_commune=="62110"
replace code_commune="62178" if code_commune=="62482"
replace code_commune="62473" if code_commune=="62575"
replace code_commune="63303" if code_commune=="63217"
replace code_commune="65141" if code_commune=="65008"
replace code_commune="65003" if code_commune=="65365"
replace code_commune="66010" if code_commune=="66200"
replace code_commune="67474" if code_commune=="67211"
replace code_commune="68216" if code_commune=="68236"
replace code_commune="69172" if code_commune=="69011"
replace code_commune="70004" if code_commune=="70073"
replace code_commune="71443" if code_commune=="71211"
replace code_commune="71101" if code_commune=="71560"
replace code_commune="72241" if code_commune=="72206"
replace code_commune="74256" if code_commune=="74246"
replace code_commune="76217" if code_commune=="76466"   
replace code_commune="79195" if code_commune=="79017"
replace code_commune="79013" if code_commune=="79037"
replace code_commune="79013" if code_commune=="79305"
replace code_commune="80369" if code_commune=="80370"
replace code_commune="80086" if code_commune=="80772"
replace code_commune="81132" if code_commune=="81107"
replace code_commune="85036" if code_commune=="85068"
replace code_commune="88106" if code_commune=="88034"
replace code_commune="88227" if code_commune=="88396"
replace code_commune="89014" if code_commune=="89140"

 
*
 
merge m:1 code_commune using "$nomenclatures${sep}table_passage_2003_2019.dta"

replace codgeo_2019 = code_commune if codgeo_2019==""
drop if _merge==2
drop code_commune _merge
rename codgeo_2019 code_commune
 
merge m:1 code_commune using "$nomenclatures${sep}AU2010.dta"
drop if _merge==2
drop _merge commune

*
 
merge m:1 code_commune using "$nomenclatures${sep}UU2010_final.dta"
drop if _merge==2
drop _merge commune

}
*
 
***Keep only one obs by individual x year
 
sort idnr year sb
by idnr year: keep if _n==_N
duplicates drop idnr year, force

sort idnr year
egen personid = group(idnr)


***Save dataset
 
compress

save "$processing${sep}panel_dads_edp_1991_2016_extended.dta", replace

keep idnr personid year code_commune dep dp code_au2010 au2010 code_uu2010 uu2010 statut_2012 total_hours empty_hours nbsa_et nbsa_ent apen apet apen2 apet2 nbheur cs1 cs2 pcs4 pcs_v2 xp ancsir private ce siren siret educ siren_dec siret_dec
order idnr personid year code_commune dep code_au2010 au2010 code_uu2010 uu2010 statut_2012

save "$maindir_replication${sep}Part_B${sep}dta${sep}additional_var.dta", replace

}
*

