


			*****************
			***Master Code***
			*****************


*************
***Folders***
*************

{

global unix=0  // Please change to 1 if you run stata on Unix or Mac

if($unix==1){
	global sep="/"
}
else{
	global sep="\"
}

**Main Paths

global maindir_replication ="...${sep}Replication_package_QE" //Please change to main directory

global data ="$maindir_replication${sep}Data"
global sources ="$maindir_replication${sep}Data${sep}Sources"
global processing ="$maindir_replication${sep}Data${sep}Processing"
global nomenclatures ="$maindir_replication${sep}Data${sep}Nomenclatures"

global part_A ="$maindir_replication${sep}Part_A"
global part_B ="$maindir_replication${sep}Part_B"


**Main Folders

capture noisily mkdir "$maindir_replication${sep}Data"
capture noisily mkdir "$maindir_replication${sep}Data${sep}Sources"
capture noisily mkdir "$maindir_replication${sep}Data${sep}Processing"
capture noisily mkdir "$maindir_replication${sep}Data${sep}Nomenclatures"

capture noisily mkdir "$maindir_replication${sep}Part_A"
capture noisily mkdir "$maindir_replication${sep}Part_A${sep}do"
capture noisily mkdir "$maindir_replication${sep}Part_A${sep}dta"
capture noisily mkdir "$maindir_replication${sep}Part_A${sep}figs"
capture noisily mkdir "$maindir_replication${sep}Part_A${sep}figs${sep}Descriptive_stats"
capture noisily mkdir "$maindir_replication${sep}Part_A${sep}figs${sep}Additional_figs"
capture noisily mkdir "$maindir_replication${sep}Part_A${sep}log"
capture noisily mkdir "$maindir_replication${sep}Part_A${sep}out"

capture noisily mkdir "$maindir_replication${sep}Part_B"
capture noisily mkdir "$maindir_replication${sep}Part_B${sep}do"
capture noisily mkdir "$maindir_replication${sep}Part_B${sep}dta"
capture noisily mkdir "$maindir_replication${sep}Part_B${sep}figs"

capture noisily mkdir "$maindir_replication${sep}Part_B${sep}local"
foreach var in paris central suburbs remote rural {
	capture noisily mkdir "$maindir_replication${sep}Part_B${sep}local${sep}`var'"
	capture noisily mkdir "$maindir_replication${sep}Part_B${sep}local${sep}`var'${sep}dta"
	capture noisily mkdir "$maindir_replication${sep}Part_B${sep}local${sep}`var'${sep}figs"
	capture noisily mkdir "$maindir_replication${sep}Part_B${sep}local${sep}`var'${sep}log"
	capture noisily mkdir "$maindir_replication${sep}Part_B${sep}local${sep}`var'${sep}out"
}
*

**Folder "$maindir_replication${sep}do" must contain the following codes:
/*
	-"0a_export_panel_ts_edp_2018": converts SAS data to Stata (EDP)
	-"0b_clean_panel_ts_edp_2018": cleans education data
	-"0c_export_panel_ts_2018": converts SAS data to Stata (LEED)
	-"0d_clean_panel_ts_2018": cleans LEED data
	-"0e_additional_data": prepares data for figures specific to France

	-"1_master_code"
	
	-Codes that allow to replicate Part A at the local level (see below)
	-"2a_Initialize_local"
	-"2b_Gen_Base_Sample_local"
	-"2c_Inequality_local"
	-"2d_Paper_Figs_local"
	-"2e_myplots_local"
	-"2f_myprogs_local"
*/

**Folder "$maindir_replication${sep}Data${sep}Nomenclatures" must contain the following data:
/*
	-"AU2010": match between municipality code and urban areas
	-"ZE1990": match between municipality code and commuting zones (1990)
	-"ZE2010": match between municipality code and commuting zones (2010)
	-"UU2010_final": match between municipality code and urban units
	-"table_passage_2003_2019": used to update old municipality codes
	-"local_cpi": table of local CPI
	-"pop_au2010_2015": population of urban areas in 2015 (census data)
	-"population_1968_2015_final": population at municipality level between 1968-2015 (census data)
*/

**Folder "$maindir_replication${sep}Part_A${sep}do" must contain the following codes:
/*
	-"0_Initialize": initializes the parameters used in the following codes (e.g. age of the workforce, period of analysis, CPI, minimum wage, name of the main variables, etc.). This dofile must be modified accordingly. 
	-"1_Gen_Base_Sample": produces the main dataset at the individual level including all measures of earnings (e.g. log earninigs, residual earnings, permanent earnings, growth rate at one and five years, etc.)
	-"2_Descriptive_Stats": generates summary statistics for the whole sample and by group (gender, age, level of education)
	-"3_Inequality": generates inequality measures (see section 3.1)
	-"4_Volatility": generates measures of earnings volatility (see section 3.2)
	-"5_Mobility": generates statistics on relative earnings mobility over the lifecycle of individuals (see section 3.3)
	-"6_Insheeting_datasets": produces the data that are available on the GRID website (grid-database.org/data-center)
	-"7_Paper_Figs": generates the main figures that appear in the paper (see section 2 and Appendix sections C-G)
	-"myplots": defines the graph settings used in code 7 to plot the main statistics
	-"myprogs": defines the functions that are used in codes 3, 4 and 5 to produce the harmonized statistics

	-"descriptive_stats": additional descriptive statistics
	-"additional_figures": additional figures on national inequality that are specific to France (e.g. hourly wage, 2002 workweek reduction, etc.)
*/

**Folder "$maindir_replication${sep}Part_B${sep}do" must contain the following codes:
*	-additional_figures_partB: figures for part B


}
*

		************
		***Part A***
		************


*******************
***Data Cleaning***
*******************

{

*You must run "0a_export_panel_ts_edp_2018" & "0c_export_panel_ts_2018" to convert data from SAS to Stata
*change paths to save datasets in "$maindir_replication${sep}Data${sep}Sources"

***Panel tous salariés + EDP
*Level of education from census data

do "$maindir_replication${sep}do${sep}0b_clean_panel_ts_edp_2018"

***Panel tous salariés
*Clean wage data
*Merge them with the level of education from EDP

do "$maindir_replication${sep}do${sep}0d_clean_panel_ts_2018"

}
*



**************
***Analysis***
**************

{

global maindir ="$maindir_replication${sep}Part_A"

***Generate main sample
clear all
do "$maindir${sep}do${sep}1_Gen_Base_Sample"

***Summary statistics
clear all
do "$maindir${sep}do${sep}2_Descriptive_Stats"

***Inequality statistics
clear all
do "$maindir${sep}do${sep}3_Inequality"

***Volatility statistics
clear all
do "$maindir${sep}do${sep}4_Volatility"

***Statistics on earnings mobility
clear all
global numestates = "1 3 5 10 15"		// How many years ahead mobility 3 5 10 15
global mathetgroup = `" "" "male agegp" male "' // Mobility conditional this groups
do "$maindir${sep}do${sep}5_Mobility"

***Produce main data for GRID (online) database

// Where the data are stored //Please change with the date when the code is ran
global ineqdata = " 2 Jul 2022 Inequality"			// Data on Inequality 
global voladata = " 2 Jul 2022 Volatility"				// Data on Volatility
global mobidata = " 2 Jul 2022 Mobility"				// Data on Mobility

global exrate2018 = 1 //values expressed in euros
					  //modify "$maindir${sep}do${sep}0_Initialize" accordingly otherwise
					  
// Where the new data wil be stored
global datafran="$maindir${sep}out${sep}2 Jul 2022 Upload"

clear all
do "$maindir${sep}do${sep}6_Insheeting_datasets"

***Produces additional data for Part A & B
do "$maindir_replication${sep}do${sep}0e_additional_data"

***Main plots of Part A (common to all papers)

// Where the figures are going to be saved 
global outfolder="2022.02.07"		

// Define these variables for your dataset
global yrfirst = 1991 					// First year in the dataset 
global yrlast =  2016 					// Last year in the dataset	

*For Tcommon, project guideline recommend  Tcommon=min{Tmax, 20}
*This affects only the time period for the plots

global Tcommon = ${yrlast} - 20 + 1	

// Which section are ploted
	global figineq =  "yes"			// Inequality
	global figcoh =   "yes"			// Cohorts and initial inequality
	global figvol =   "yes"			// Volatility
	global figquan =  "yes"			// Income growth heterogeneity 
	global figmob =   "yes"			// Mobility
	global figtail =  "yes"			// Tail 
	global figcon =   "yes"			// Concentration 
	global figden =   "yes"			// Density Plots

clear all
do "$maindir${sep}do${sep}7_Paper_Figs"


***Additional descriptive statistics
clear all
global desc_stats = " 2 Jul 2022 Descriptive_Stat"			// Data produced by "$maindir${sep}do${sep}2_Descriptive_Stats"
															// Please change with the name of the folder where the data are stored
do "$maindir${sep}do${sep}descriptive_stats"


***Additional figures
clear all
do "$maindir${sep}do${sep}additional_figures"

}
*



		************
		***Part B***
		************
	
******************
***Main Figures***
******************

{

***Main figures of part B
clear all
global maindir ="$maindir_replication${sep}Part_B"
do "$maindir${sep}do${sep}additional_figures_partB"


***Figures 19-20 
*Reproduce inequality graphs of part A at local level (Paris, Central municipalities, Suburbs, Remote municipalities, Rural municipalities)

foreach var in paris central suburbs remote rural  { //paris central suburbs remote rural 

	clear all
	global maindir ="$maindir_replication${sep}Part_B${sep}local${sep}`var'"

	***Generate main sample
	do "$maindir_replication${sep}do${sep}2b_Gen_Base_Sample_local"

	***Inequality statistics
	do "$maindir_replication${sep}do${sep}2c_Inequality_local"

	// Where the data are stored
	global ineqdata = " 2 Jul 2022 Inequality"			// Data on Inequality 
														// Please change with the name of the folder where the data are stored
	
	// Where the figures are going to be saved 
	global outfolder="2022.02.07"		

	// Define these variables for your dataset
	global yrfirst = 1993 					// First year in the dataset 
	global yrlast =  2016 					// Last year in the dataset	

	*Project guideline recommend  Tcommon=min{Tmax, 20}
	
	global Tcommon = ${yrlast} - 20 + 1	

	// Which section are ploted
		global figineq =  "yes"			// Inequality
		global figcoh =   "no"			// Cohorts and initial inequality
		global figtail =  "no"			// Tail 
		global figcon =   "no"			// Concentration 

	do "$maindir_replication${sep}do${sep}2d_Paper_Figs_local"

}
*

}
*

